# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cluster_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63luster_manager.proto\"\x19\n\nStopPidMsg\x12\x0b\n\x03pid\x18\x01 \x01(\x05\"\x1a\n\x0b\x43heckPidMsg\x12\x0b\n\x03pid\x18\x01 \x01(\x05\"S\n\x13StartSparkServerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"R\n\x12StopSparkServerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"?\n\x14StartSparkServersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\">\n\x13StopSparkServersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"Y\n\x1dGetExecutionTimeSeriesDataMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x0f\n\x07minutes\x18\x03 \x01(\x05\"\xa1\x0b\n\x1d\x45mulationMetricsTimeSeriesDTO\x12\x33\n\x0e\x63lient_metrics\x18\x01 \x03(\x0b\x32\x1b.ClientPopulationMetricsDTO\x12\x30\n\x17\x61ggregated_docker_stats\x18\x02 \x03(\x0b\x32\x0f.DockerStatsDTO\x12+\n\x11\x64ocker_host_stats\x18\x03 \x03(\x0b\x32\x10.DockerStatsDict\x12&\n\x0chost_metrics\x18\x04 \x03(\x0b\x32\x10.HostMetricsDict\x12\x34\n\x17\x61ggregated_host_metrics\x18\x05 \x03(\x0b\x32\x13.HostMetricsDataDTO\x12\x35\n\x10\x64\x65\x66\x65nder_actions\x18\x06 \x03(\x0b\x32\x1b.EmulationDefenderActionDTO\x12\x35\n\x10\x61ttacker_actions\x18\x07 \x03(\x0b\x32\x1b.EmulationAttackerActionDTO\x12\x38\n\x15\x61gg_snort_ids_metrics\x18\x08 \x03(\x0b\x32\x19.SnortIdsAlertCountersDTO\x12\x14\n\x0c\x65mulation_id\x18\t \x01(\x05\x12=\n\x19ossec_host_alert_counters\x18\n \x03(\x0b\x32\x1a.OSSECIdsAlertCountersDict\x12G\n$aggregated_ossec_host_alert_counters\x18\x0b \x03(\x0b\x32\x19.OSSECIdsAlertCountersDTO\x12.\n\x13openflow_flow_stats\x18\x0c \x03(\x0b\x32\x11.FlowStatisticDTO\x12.\n\x13openflow_port_stats\x18\r \x03(\x0b\x32\x11.PortStatisticDTO\x12\x35\n\x17\x61vg_openflow_flow_stats\x18\x0e \x03(\x0b\x32\x14.AvgFlowStatisticDTO\x12\x35\n\x17\x61vg_openflow_port_stats\x18\x0f \x03(\x0b\x32\x14.AvgPortStatisticDTO\x12<\n openflow_flow_metrics_per_switch\x18\x10 \x03(\x0b\x32\x12.FlowStatisticDict\x12<\n openflow_port_metrics_per_switch\x18\x11 \x03(\x0b\x32\x12.PortStatisticDict\x12\x43\n$openflow_flow_avg_metrics_per_switch\x18\x12 \x03(\x0b\x32\x15.AvgFlowStatisticDict\x12\x43\n$openflow_port_avg_metrics_per_switch\x18\x13 \x03(\x0b\x32\x15.AvgPortStatisticDict\x12\x43\n$agg_openflow_flow_metrics_per_switch\x18\x14 \x03(\x0b\x32\x15.AggFlowStatisticDict\x12\x35\n\x17\x61gg_openflow_flow_stats\x18\x15 \x03(\x0b\x32\x14.AggFlowStatisticDTO\x12<\n\x1a\x61gg_snort_ids_rule_metrics\x18\x16 \x03(\x0b\x32\x18.SnortIdsRuleCountersDTO\x12:\n\x14snort_ids_ip_metrics\x18\x17 \x03(\x0b\x32\x1c.SnortIdsIpAlertCountersDict\x12=\n\x1asnort_rule_metrics_per_ids\x18\x18 \x03(\x0b\x32\x19.SnortIdsRuleCountersDict\x12?\n\x1bsnort_alert_metrics_per_ids\x18\x19 \x03(\x0b\x32\x1a.SnortIdsAlertCountersDict\"G\n\x14\x41vgPortStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x14.AvgPortStatisticDTO\"G\n\x14\x41ggFlowStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x14.AggFlowStatisticDTO\"G\n\x14\x41vgFlowStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x14.AvgFlowStatisticDTO\"A\n\x11PortStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x11.PortStatisticDTO\"A\n\x11\x46lowStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x11.FlowStatisticDTO\"Q\n\x19OSSECIdsAlertCountersDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x19.OSSECIdsAlertCountersDTO\"A\n\x0fHostMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x13.HostMetricsDataDTO\"=\n\x0f\x44ockerStatsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x0f.DockerStatsDTO\"\xbc\x04\n\x13\x41vgPortStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\"\n\x1atotal_num_received_packets\x18\x03 \x01(\x03\x12 \n\x18total_num_received_bytes\x18\x04 \x01(\x03\x12!\n\x19total_num_received_errors\x18\x05 \x01(\x03\x12%\n\x1dtotal_num_transmitted_packets\x18\x06 \x01(\x03\x12#\n\x1btotal_num_transmitted_bytes\x18\x07 \x01(\x03\x12$\n\x1ctotal_num_transmitted_errors\x18\x08 \x01(\x03\x12\"\n\x1atotal_num_received_dropped\x18\t \x01(\x03\x12%\n\x1dtotal_num_transmitted_dropped\x18\n \x01(\x03\x12\'\n\x1ftotal_num_received_frame_errors\x18\x0b \x01(\x03\x12)\n!total_num_received_overrun_errors\x18\x0c \x01(\x03\x12%\n\x1dtotal_num_received_crc_errors\x18\r \x01(\x03\x12\x1c\n\x14total_num_collisions\x18\x0e \x01(\x03\x12 \n\x18\x61vg_duration_nanoseconds\x18\x0f \x01(\x03\x12\x1c\n\x14\x61vg_duration_seconds\x18\x10 \x01(\x03\"\x8f\x02\n\x13\x41vgFlowStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\x19\n\x11total_num_packets\x18\x03 \x01(\x03\x12\x17\n\x0ftotal_num_bytes\x18\x04 \x01(\x03\x12 \n\x18\x61vg_duration_nanoseconds\x18\x05 \x01(\x03\x12\x1c\n\x14\x61vg_duration_seconds\x18\x06 \x01(\x03\x12\x18\n\x10\x61vg_hard_timeout\x18\x07 \x01(\x03\x12\x18\n\x10\x61vg_idle_timeout\x18\x08 \x01(\x03\x12\x14\n\x0c\x61vg_priority\x18\t \x01(\x03\x12\x12\n\navg_cookie\x18\n \x01(\x03\"\x8a\x01\n\x13\x41ggFlowStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\x19\n\x11total_num_packets\x18\x03 \x01(\x03\x12\x17\n\x0ftotal_num_bytes\x18\x04 \x01(\x03\x12\x17\n\x0ftotal_num_flows\x18\x05 \x01(\x03\"\xf7\x03\n\x10PortStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x03\x12\x1c\n\x14num_received_packets\x18\x04 \x01(\x03\x12\x1a\n\x12num_received_bytes\x18\x05 \x01(\x03\x12\x1b\n\x13num_received_errors\x18\x06 \x01(\x03\x12\x1f\n\x17num_transmitted_packets\x18\x07 \x01(\x03\x12\x1d\n\x15num_transmitted_bytes\x18\x08 \x01(\x03\x12\x1e\n\x16num_transmitted_errors\x18\t \x01(\x03\x12\x1c\n\x14num_received_dropped\x18\n \x01(\x03\x12\x1f\n\x17num_transmitted_dropped\x18\x0b \x01(\x03\x12!\n\x19num_received_frame_errors\x18\x0c \x01(\x03\x12#\n\x1bnum_received_overrun_errors\x18\r \x01(\x03\x12\x1f\n\x17num_received_crc_errors\x18\x0e \x01(\x03\x12\x16\n\x0enum_collisions\x18\x0f \x01(\x03\x12\x1c\n\x14\x64uration_nanoseconds\x18\x10 \x01(\x03\x12\x18\n\x10\x64uration_seconds\x18\x11 \x01(\x03\"\xa4\x02\n\x10\x46lowStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\x0f\n\x07in_port\x18\x03 \x01(\t\x12\x10\n\x08out_port\x18\x04 \x01(\t\x12\x17\n\x0f\x64st_mac_address\x18\x05 \x01(\t\x12\x13\n\x0bnum_packets\x18\x06 \x01(\x03\x12\x11\n\tnum_bytes\x18\x07 \x01(\x03\x12\x1c\n\x14\x64uration_nanoseconds\x18\x08 \x01(\x03\x12\x18\n\x10\x64uration_seconds\x18\t \x01(\x03\x12\x14\n\x0chard_timeout\x18\n \x01(\x03\x12\x14\n\x0cidle_timeout\x18\x0b \x01(\x03\x12\x10\n\x08priority\x18\x0c \x01(\x03\x12\x0e\n\x06\x63ookie\x18\r \x01(\x03\"\xc5\x01\n\x18OSSECIdsAlertCountersDTO\x12\x14\n\x0clevel_alerts\x18\x01 \x03(\x05\x12\x14\n\x0cgroup_alerts\x18\x02 \x03(\x05\x12\x15\n\rsevere_alerts\x18\x03 \x01(\x05\x12\x16\n\x0ewarning_alerts\x18\x04 \x01(\x05\x12\x14\n\x0ctotal_alerts\x18\x05 \x01(\x05\x12 \n\x18\x61lerts_weighted_by_level\x18\x06 \x01(\x02\x12\n\n\x02ip\x18\x07 \x01(\t\x12\n\n\x02ts\x18\x08 \x01(\x02\"\xb5\x01\n\x18SnortIdsAlertCountersDTO\x12\x17\n\x0fpriority_alerts\x18\x01 \x03(\x05\x12\x14\n\x0c\x63lass_alerts\x18\x02 \x03(\x05\x12\x15\n\rsevere_alerts\x18\x03 \x01(\x05\x12\x16\n\x0ewarning_alerts\x18\x04 \x01(\x05\x12#\n\x1b\x61lerts_weighted_by_priority\x18\x05 \x01(\x02\x12\n\n\x02ip\x18\x06 \x01(\t\x12\n\n\x02ts\x18\x07 \x01(\x02\"U\n\x1bSnortIdsIpAlertCountersDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x1b.SnortIdsIpAlertCountersDTO\"Q\n\x19SnortIdsAlertCountersDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x19.SnortIdsAlertCountersDTO\"O\n\x18SnortIdsRuleCountersDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x18.SnortIdsRuleCountersDTO\"\xc9\x01\n\x1aSnortIdsIpAlertCountersDTO\x12\x17\n\x0fpriority_alerts\x18\x01 \x03(\x05\x12\x14\n\x0c\x63lass_alerts\x18\x02 \x03(\x05\x12\x15\n\rsevere_alerts\x18\x03 \x01(\x05\x12\x16\n\x0ewarning_alerts\x18\x04 \x01(\x05\x12#\n\x1b\x61lerts_weighted_by_priority\x18\x05 \x01(\x02\x12\n\n\x02ip\x18\x06 \x01(\t\x12\n\n\x02ts\x18\x07 \x01(\x02\x12\x10\n\x08\x61lert_ip\x18\x08 \x01(\t\"^\n\x17SnortIdsRuleCountersDTO\x12\x10\n\x08rule_ids\x18\x01 \x03(\t\x12\x19\n\x11rule_alert_counts\x18\x02 \x03(\x05\x12\n\n\x02ip\x18\x03 \x01(\t\x12\n\n\x02ts\x18\x04 \x01(\x02\"\xf4\x01\n\x1a\x45mulationAttackerActionDTO\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63mds\x18\x03 \x03(\t\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\r\n\x05\x64\x65scr\x18\x05 \x01(\t\x12\x0b\n\x03ips\x18\x06 \x03(\t\x12\r\n\x05index\x18\x07 \x01(\x05\x12\x16\n\x0e\x61\x63tion_outcome\x18\x08 \x01(\x05\x12\x10\n\x08\x61lt_cmds\x18\t \x03(\t\x12\x16\n\x0e\x65xecution_time\x18\n \x01(\x02\x12\n\n\x02ts\x18\x0b \x01(\x02\x12\x15\n\rvulnerability\x18\x0c \x01(\t\x12\x10\n\x08\x62\x61\x63kdoor\x18\r \x01(\x08\"\xcb\x01\n\x1a\x45mulationDefenderActionDTO\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63mds\x18\x03 \x03(\t\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\r\n\x05\x64\x65scr\x18\x05 \x01(\t\x12\x0b\n\x03ips\x18\x06 \x03(\t\x12\r\n\x05index\x18\x07 \x01(\x05\x12\x16\n\x0e\x61\x63tion_outcome\x18\x08 \x01(\x05\x12\x10\n\x08\x61lt_cmds\x18\t \x03(\t\x12\x16\n\x0e\x65xecution_time\x18\n \x01(\x02\x12\n\n\x02ts\x18\x0b \x01(\x02\"\xce\x01\n\x12HostMetricsDataDTO\x12\x1b\n\x13num_logged_in_users\x18\x01 \x01(\x05\x12!\n\x19num_failed_login_attempts\x18\x02 \x01(\x05\x12\x1c\n\x14num_open_connections\x18\x03 \x01(\x05\x12\x18\n\x10num_login_events\x18\x04 \x01(\x05\x12\x15\n\rnum_processes\x18\x05 \x01(\x05\x12\x11\n\tnum_users\x18\x06 \x01(\x05\x12\n\n\x02ip\x18\x07 \x01(\t\x12\n\n\x02ts\x18\x08 \x01(\x02\"\xf8\x01\n\x0e\x44ockerStatsDTO\x12\x0c\n\x04pids\x18\x01 \x01(\x02\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x63pu_percent\x18\x03 \x01(\x02\x12\x13\n\x0bmem_current\x18\x04 \x01(\x02\x12\x11\n\tmem_total\x18\x05 \x01(\x02\x12\x13\n\x0bmem_percent\x18\x06 \x01(\x02\x12\x10\n\x08\x62lk_read\x18\x07 \x01(\x02\x12\x11\n\tblk_write\x18\x08 \x01(\x02\x12\x0e\n\x06net_rx\x18\t \x01(\x02\x12\x0e\n\x06net_tx\x18\n \x01(\x02\x12\x16\n\x0e\x63ontainer_name\x18\x0b \x01(\t\x12\n\n\x02ip\x18\x0c \x01(\t\x12\n\n\x02ts\x18\r \x01(\x02\"m\n\x1a\x43lientPopulationMetricsDTO\x12\n\n\x02ip\x18\x01 \x01(\t\x12\n\n\x02ts\x18\x02 \x01(\x02\x12\x13\n\x0bnum_clients\x18\x03 \x01(\x05\x12\x0c\n\x04rate\x18\x04 \x01(\x02\x12\x14\n\x0cservice_time\x18\x05 \x01(\x02\"\x1a\n\x18GetClusterManagerLogsMsg\"S\n\x13GetContainerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"B\n\x17GetClientManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"A\n\x16GetKafkaManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\":\n\x0fGetKafkaLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"R\n\x12GetSnortIdsLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"Y\n\x19GetSnortIdsManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"Y\n\x19GetOSSECIdsManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"R\n\x12GetOSSECIdsLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"U\n\x15GetHostManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"X\n\x18GetTrafficManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"?\n\x14GetElkManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"8\n\rGetElkLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14GetRyuManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17GetRyuControllerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17StopRyuMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"C\n\x18StartRyuMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"D\n\x19StopHostMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"X\n\x18StopHostMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"@\n\x15RemoveKibanaTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15\x43reateKibanaTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\x16\n\x14ListKibanaTunnelsMsg\"5\n\x10KibanaTunnelsDTO\x12!\n\x07tunnels\x18\x01 \x03(\x0b\x32\x10.KibanaTunnelDTO\"T\n\x0fKibanaTunnelDTO\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x11\n\temulation\x18\x03 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x04 \x01(\x05\"=\n\x12RemoveRyuTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12\x43reateRyuTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\x13\n\x11ListRyuTunnelsMsg\"/\n\rRyuTunnelsDTO\x12\x1e\n\x07tunnels\x18\x01 \x03(\x0b\x32\r.RyuTunnelDTO\"Q\n\x0cRyuTunnelDTO\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x11\n\temulation\x18\x03 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x04 \x01(\x05\"P\n SnortIdsMonitorThreadStatusesDTO\x12,\n\x10snortIDSStatuses\x18\x01 \x03(\x0b\x32\x12.SnortIdsStatusDTO\"E\n\x1aGetSnortIdsManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"N\n#GetSnortIdsMonitorThreadStatusesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"H\n\x1dStopSnortIdsMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"V\n\x16StopSnortIdsManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"W\n\x17StartSnortIdsManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"B\n\x17StopSnortIdsManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"C\n\x18StartSnortIdsManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"M\n\rStartSnortMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"]\n\x1dStartSnortIdsMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"I\n\x1eStartSnortIdsMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"L\n\x0cStopSnortMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"\\\n\x1cStopSnortIdsMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"<\n\x11StopSnortIdsesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"J\n\x1fStopSnortIdsesMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15GetRyuManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"C\n\x18StopRyuMonitorServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"D\n\x19StartRyuMonitorServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"<\n\x11StopRyuServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StartRyuServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"A\n\x16GetRyuServiceStatusMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"<\n\x11StopRyuManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StartRyuManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"E\n\x1aGetOSSECIDSManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"P\n OSSECIdsMonitorThreadStatusesDTO\x12,\n\x10ossecIDSStatuses\x18\x01 \x03(\x0b\x32\x12.OSSECIdsStatusDTO\"N\n#GetOSSECIDSMonitorThreadStatusesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"H\n\x1dStopOSSECIDSMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\\\n\x1cStopOSSECIDSMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"]\n\x1dStartOSSECIDSMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"S\n\x13StopOSSECIDSManager\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"T\n\x14StartOSSECIDSManager\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"?\n\x14StopOSSECIDSManagers\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15StartOSSECIDSManagers\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"P\n\x10StartOSSECIDSMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"O\n\x0fStopOSSECIDSMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"=\n\x12StartOSSECIDSesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"<\n\x11StopOSSECIDSesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17GetKafkaManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\">\n\x13StartKafkaServerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StopKafkaServerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"C\n\x18GetKafkaManagerStatusMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14\x43reateKafkaTopicsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\">\n\x13StopKafkaManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14StartKafkaManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"A\n\x16GetHostManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"K\n GetHostMonitorThreadsStatusesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"V\n\x16\x41pplyFileBeatConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"X\n\x18\x41pplyPacketBeatConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"X\n\x18\x41pplyMetricBeatConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"W\n\x17\x41pplyHeartBeatConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"O\n\x0fStopFileBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"Q\n\x11StopPacketBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"Q\n\x11StopMetricBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"P\n\x10StopHeartBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"f\n\x10StartFileBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ontainerIp\x18\x04 \x01(\t\"h\n\x12StartPacketBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ontainerIp\x18\x04 \x01(\t\"h\n\x12StartMetricBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ontainerIp\x18\x04 \x01(\t\"g\n\x11StartHeartBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ontainerIp\x18\x04 \x01(\t\"Y\n\x19StartHostMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"<\n\x11StopHeartbeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StopPacketbeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\";\n\x10StopFilebeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StopMetricbeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"E\n\x1aStartHostMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"R\n\x12StopHostManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"S\n\x13StartHostManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\">\n\x13StopHostManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\xad\x05\n\x10\x45xecutionInfoDTO\x12\x15\n\remulationName\x18\x01 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x02 \x01(\x05\x12\x36\n\x14snortIdsManagersInfo\x18\x03 \x01(\x0b\x32\x18.SnortIdsManagersInfoDTO\x12\x36\n\x14ossecIdsManagersInfo\x18\x04 \x01(\x0b\x32\x18.OSSECIdsManagersInfoDTO\x12\x30\n\x11kafkaManagersInfo\x18\x05 \x01(\x0b\x32\x15.KafkaManagersInfoDTO\x12.\n\x10hostManagersInfo\x18\x06 \x01(\x0b\x32\x14.HostManagersInfoDTO\x12\x32\n\x12\x63lientManagersInfo\x18\x07 \x01(\x0b\x32\x16.ClientManagersInfoDTO\x12<\n\x17\x64ockerStatsManagersInfo\x18\x08 \x01(\x0b\x32\x1b.DockerStatsManagersInfoDTO\x12\x30\n\x11runningContainers\x18\t \x01(\x0b\x32\x15.RunningContainersDTO\x12\x30\n\x11stoppedContainers\x18\n \x01(\x0b\x32\x15.StoppedContainersDTO\x12\x37\n\x16trafficManagersInfoDTO\x18\x0b \x01(\x0b\x32\x17.TrafficManagersInfoDTO\x12*\n\x0e\x61\x63tiveNetworks\x18\x0c \x01(\x0b\x32\x12.DockerNetworksDTO\x12/\n\x12\x65lkManagersInfoDTO\x18\r \x01(\x0b\x32\x13.ElkManagersInfoDTO\x12/\n\x12ryuManagersInfoDTO\x18\x0e \x01(\x0b\x32\x13.RyuManagersInfoDTO\"\xe5\x01\n\x12RyuManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1a\n\x12ryuManagersRunning\x18\x05 \x03(\x08\x12\x31\n\x13ryuManagersStatuses\x18\x06 \x03(\x0b\x32\x14.RyuManagerStatusDTO\x12\x1e\n\x16localControllerWebPort\x18\x07 \x01(\x05\x12\x18\n\x10physicalServerIp\x18\x08 \x01(\t\"\xb4\x01\n\x13RyuManagerStatusDTO\x12\x13\n\x0bryu_running\x18\x01 \x01(\x08\x12\x17\n\x0fmonitor_running\x18\x02 \x01(\x08\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x10\n\x08web_port\x18\x04 \x01(\x05\x12\x12\n\ncontroller\x18\x05 \x01(\t\x12\x10\n\x08kafka_ip\x18\x06 \x01(\t\x12\x12\n\nkafka_port\x18\x07 \x01(\x05\x12\x15\n\rtime_step_len\x18\x08 \x01(\x05\"\xaf\x01\n\x13HostManagersInfoDTO\x12\x0b\n\x03ips\x18\x15 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1b\n\x13hostManagersRunning\x18\x05 \x03(\x08\x12\x33\n\x14hostManagersStatuses\x18\x06 \x03(\x0b\x32\x15.HostManagerStatusDTO\"L\n\x16HostManagerStatusesDTO\x12\x32\n\x13hostManagerStatuses\x18\x01 \x03(\x0b\x32\x15.HostManagerStatusDTO\"\xa8\x01\n\x14HostManagerStatusDTO\x12\x17\n\x0fmonitor_running\x18\x01 \x01(\x08\x12\x18\n\x10\x66ilebeat_running\x18\x02 \x01(\x08\x12\x1a\n\x12packetbeat_running\x18\x03 \x01(\x08\x12\x1a\n\x12metricbeat_running\x18\x04 \x01(\x08\x12\x19\n\x11heartbeat_running\x18\x05 \x01(\x08\x12\n\n\x02ip\x18\x06 \x01(\t\"\xac\x01\n\x14KafkaManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1c\n\x14kafkaManagersRunning\x18\x05 \x03(\x08\x12.\n\x15kafkaManagersStatuses\x18\x06 \x03(\x0b\x32\x0f.KafkaStatusDTO\"1\n\x0eKafkaStatusDTO\x12\x0f\n\x07running\x18\x01 \x01(\x08\x12\x0e\n\x06topics\x18\x02 \x03(\t\"\xb8\x01\n\x17OSSECIdsManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1f\n\x17ossecIdsManagersRunning\x18\x05 \x03(\x08\x12\x34\n\x18ossecIdsManagersStatuses\x18\x06 \x03(\x0b\x32\x12.OSSECIdsStatusDTO\"G\n\x11OSSECIdsStatusDTO\x12\x17\n\x0fmonitor_running\x18\x01 \x01(\x08\x12\x19\n\x11ossec_ids_running\x18\x02 \x01(\x08\"\xb8\x01\n\x17SnortIdsManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1f\n\x17snortIdsManagersRunning\x18\x05 \x03(\x08\x12\x34\n\x18snortIdsManagersStatuses\x18\x06 \x03(\x0b\x32\x12.SnortIdsStatusDTO\"G\n\x11SnortIdsStatusDTO\x12\x17\n\x0fmonitor_running\x18\x01 \x01(\x08\x12\x19\n\x11snort_ids_running\x18\x02 \x01(\x08\">\n\x13GetExecutionInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"G\n\x1cStopContainersOfExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"y\n\x0fRunContainerMsg\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06memory\x18\x03 \x01(\x05\x12\x10\n\x08num_cpus\x18\x04 \x01(\x05\x12\x16\n\x0e\x63reate_network\x18\x05 \x01(\x08\x12\x0f\n\x07version\x18\x06 \x01(\t\"H\n\x1dStartContainersOfExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15GetElkManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\xd7\x01\n\x12\x45lkManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1a\n\x12\x65lkManagersRunning\x18\x05 \x03(\x08\x12*\n\x13\x65lkManagersStatuses\x18\x06 \x03(\x0b\x32\r.ElkStatusDTO\x12\x17\n\x0flocalKibanaPort\x18\x07 \x01(\x05\x12\x18\n\x10physicalServerIp\x18\x08 \x01(\t\"A\n\x16StopLogstashServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17StartLogstashServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14StopKibanaServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15StartKibanaServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15StopElasticServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"A\n\x16StartElasticServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\":\n\x0fStopElkStackMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"V\n\x0c\x45lkStatusDTO\x12\x16\n\x0e\x65lasticRunning\x18\x01 \x01(\x08\x12\x15\n\rkibanaRunning\x18\x02 \x01(\x08\x12\x17\n\x0flogstashRunning\x18\x03 \x01(\x08\"?\n\x14GetElkStackStatusMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"<\n\x11StopElkManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StartElkManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"H\n\x1dGetDockerStatsManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\xcb\x01\n\x1a\x44ockerStatsManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\"\n\x1a\x64ockerStatsManagersRunning\x18\x05 \x03(\x08\x12\x41\n\x1b\x64ockerStatsManagersStatuses\x18\x06 \x03(\x0b\x32\x1c.DockerStatsMonitorStatusDTO\"\x1c\n\x1aRemoveAllDockerNetworksMsg\"+\n\x17RemoveDockerNetworksMsg\x12\x10\n\x08networks\x18\x01 \x03(\t\"e\n\x1b\x44ockerStatsMonitorStatusDTO\x12\x14\n\x0cnum_monitors\x18\x01 \x01(\x05\x12\x12\n\nemulations\x18\x02 \x03(\t\x12\x1c\n\x14\x65mulation_executions\x18\x03 \x03(\x05\".\n\x1eGetDockerStatsManagerStatusMsg\x12\x0c\n\x04port\x18\x01 \x01(\x05\"J\n\x1fStopDockerStatsManagerThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"E\n\x1a\x43reateEmulationNetworksMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\x1d\n\x1bListAllStoppedContainersMsg\"F\n\x14StoppedContainersDTO\x12.\n\x11stoppedContainers\x18\x01 \x03(\x0b\x32\x13.DockerContainerDTO\"\x1d\n\x1bListAllRunningEmulationsMsg\"1\n\x14RunningEmulationsDTO\x12\x19\n\x11runningEmulations\x18\x01 \x03(\t\"\x1d\n\x1bListAllRunningContainersMsg\"F\n\x14RunningContainersDTO\x12.\n\x11runningContainers\x18\x01 \x03(\x0b\x32\x13.DockerContainerDTO\"=\n\x12\x44ockerContainerDTO\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\n\n\x02ip\x18\x03 \x01(\t\"!\n\x11StartContainerMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1e\n\x1cStartAllStoppedContainersMsg\"\x1a\n\x18ListAllDockerNetworksMsg\":\n\x11\x44ockerNetworksDTO\x12\x10\n\x08networks\x18\x01 \x03(\t\x12\x13\n\x0bnetwork_ids\x18\x02 \x03(\x05\"8\n\x12\x43ontainerImagesDTO\x12\"\n\x06images\x18\x01 \x03(\x0b\x32\x12.ContainerImageDTO\"f\n\x11\x43ontainerImageDTO\x12\x10\n\x08repoTags\x18\x01 \x01(\t\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\n\n\x02os\x18\x03 \x01(\t\x12\x14\n\x0c\x61rchitecture\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\x03\"\x1b\n\x19ListAllContainerImagesMsg\"\'\n\x17RemoveContainerImageMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1d\n\x1bRemoveAllContainerImagesMsg\"\x1f\n\x1dRemoveAllStoppedContainersMsg\"\"\n\x12RemoveContainerMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\" \n\x10StopContainerMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1d\n\x1bStopAllRunningContainersMsg\"D\n\x19GetTrafficManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\xb9\x01\n\x16TrafficManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1e\n\x16trafficManagersRunning\x18\x05 \x03(\x08\x12\x37\n\x17trafficManagersStatuses\x18\x06 \x03(\x0b\x32\x16.TrafficManagerInfoDTO\"8\n\x15TrafficManagerInfoDTO\x12\x0f\n\x07running\x18\x01 \x01(\x08\x12\x0e\n\x06script\x18\x02 \x01(\t\"\xb1\x01\n\x15\x43lientManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1d\n\x15\x63lientManagersRunning\x18\x05 \x03(\x08\x12\x31\n\x16\x63lientManagersStatuses\x18\x06 \x03(\x0b\x32\x11.GetNumClientsDTO\"C\n\x18GetClientManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"X\n\x18StartTrafficGeneratorMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"W\n\x17StopTrafficGeneratorMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"C\n\x18StopTrafficGeneratorsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\xae\x01\n\x10GetNumClientsDTO\x12\x13\n\x0bnum_clients\x18\x01 \x01(\x05\x12\x1d\n\x15\x63lient_process_active\x18\x02 \x01(\x08\x12\x17\n\x0fproducer_active\x18\x03 \x01(\x08\x12%\n\x1d\x63lients_time_step_len_seconds\x18\x04 \x01(\x05\x12&\n\x1eproducer_time_step_len_seconds\x18\x05 \x01(\x05\"A\n\x16GetNumActiveClientsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17StopClientPopulationMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14StopClientManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15StartClientManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"A\n\x16StopTrafficManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"U\n\x15StopTrafficManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"V\n\x16StartTrafficManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"\x17\n\x15\x43leanAllExecutionsMsg\"\x16\n\x14StopAllExecutionsMsg\";\n\x10StopExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"<\n\x11\x43leanExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"4\n\x1fStopAllExecutionsOfEmulationMsg\x12\x11\n\temulation\x18\x01 \x01(\t\"5\n CleanAllExecutionsOfEmulationMsg\x12\x11\n\temulation\x18\x01 \x01(\t\"\x14\n\x12GetCsleLogFilesMsg\"\x1d\n\rGetLogFileMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\"H\n\x1dStartContainersInExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"S\n(AttachContainersToNetworksInExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\">\n\x13InstallLibrariesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\">\n\x13\x41pplyKafkaConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15StartSdnControllerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"E\n\x1a\x41pplyResouceConstraintsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14\x43reateOvsSwitchesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\";\n\x10PingExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\":\n\x0f\x43onfigureOvsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"G\n\x1cStartSdnControllerMonitorMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"9\n\x0e\x43reateUsersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"9\n\x0e\x43reateVulnsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"9\n\x0e\x43reateFlagsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"<\n\x11\x43reateTopologyMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17StartTrafficManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"D\n\x19StartTrafficGeneratorsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"C\n\x18StartClientPopulationMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"F\n\x1bStartKafkaClientProducerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"E\n\x1aStopKafkaClientProducerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StartSnortIdsesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"K\n StartSnortIdsesMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StartOSSECIdsesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"K\n StartOSSECIdsesMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\";\n\x10StartElkStackMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14StartHostManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17\x41pplyFileBeatConfigsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"D\n\x19\x41pplyPacketBeatConfigsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"D\n\x19\x41pplyMetricBeatConfigsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"C\n\x18\x41pplyHeartBeatConfigsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"R\n\x11StartFileBeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\"T\n\x13StartPacketBeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\"T\n\x13StartMetricBeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\"S\n\x12StartHeartBeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\"\x1e\n\x1cGetDockerStatsManagerLogsMsg\"\x16\n\x14GetPrometheusLogsMsg\"\x18\n\x16GetNodeExporterLogsMsg\"\x14\n\x12GetCAdvisorLogsMsg\"\x13\n\x11GetPgAdminLogsMsg\"\x13\n\x11GetGrafanaLogsMsg\"\x11\n\x0fGetNginxLogsMsg\"\x12\n\x10GetDockerLogsMsg\"\x16\n\x14GetPostgreSQLLogsMsg\"\x11\n\x0fGetFlaskLogsMsg\"\x17\n\x07LogsDTO\x12\x0c\n\x04logs\x18\x01 \x03(\t\"&\n\x13OperationOutcomeDTO\x12\x0f\n\x07outcome\x18\x01 \x01(\x08\"\x12\n\x10GetNodeStatusMsg\"\xb3\x02\n\rNodeStatusDTO\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0e\n\x06leader\x18\x02 \x01(\x08\x12\x17\n\x0f\x63\x41\x64visorRunning\x18\x03 \x01(\x08\x12\x19\n\x11prometheusRunning\x18\x04 \x01(\x08\x12\x16\n\x0egrafanaRunning\x18\x05 \x01(\x08\x12\x16\n\x0epgAdminRunning\x18\x06 \x01(\x08\x12\x14\n\x0cnginxRunning\x18\x07 \x01(\x08\x12\x14\n\x0c\x66laskRunning\x18\x08 \x01(\x08\x12!\n\x19\x64ockerStatsManagerRunning\x18\t \x01(\x08\x12\x1b\n\x13nodeExporterRunning\x18\n \x01(\x08\x12\x19\n\x11postgreSQLRunning\x18\x0b \x01(\x08\x12\x1b\n\x13\x64ockerEngineRunning\x18\x0c \x01(\x08\"#\n\x10ServiceStatusDTO\x12\x0f\n\x07running\x18\x01 \x01(\x08\"\x14\n\x12StartPostgreSQLMsg\"\x12\n\x10StartCAdvisorMsg\"\x16\n\x14StartNodeExporterMsg\"\x11\n\x0fStartGrafanaMsg\"\x14\n\x12StartPrometheusMsg\"\x11\n\x0fStartPgAdminMsg\"\x0f\n\rStartNginxMsg\"\x0f\n\rStartFlaskMsg\"\x1c\n\x1aStartDockerStatsManagerMsg\"K\n StartDockerStatsManagerThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\x16\n\x14StartDockerEngineMsg\"\x13\n\x11StopPostgreSQLMsg\"\x11\n\x0fStopCAdvisorMsg\"\x15\n\x13StopNodeExporterMsg\"\x10\n\x0eStopGrafanaMsg\"\x13\n\x11StopPrometheusMsg\"\x10\n\x0eStopPgAdminMsg\"\x0e\n\x0cStopNginxMsg\"\x0e\n\x0cStopFlaskMsg\"\x1b\n\x19StopDockerStatsManagerMsg\"\x15\n\x13StopDockerEngineMsg2\xc1r\n\x0e\x43lusterManager\x12\x34\n\rgetNodeStatus\x12\x11.GetNodeStatusMsg\x1a\x0e.NodeStatusDTO\"\x00\x12;\n\x0fstartPostgreSQL\x12\x13.StartPostgreSQLMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x37\n\rstartCAdvisor\x12\x11.StartCAdvisorMsg\x1a\x11.ServiceStatusDTO\"\x00\x12?\n\x11startNodeExporter\x12\x15.StartNodeExporterMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x35\n\x0cstartGrafana\x12\x10.StartGrafanaMsg\x1a\x11.ServiceStatusDTO\"\x00\x12;\n\x0fstartPrometheus\x12\x13.StartPrometheusMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x35\n\x0cstartPgAdmin\x12\x10.StartPgAdminMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x31\n\nstartNginx\x12\x0e.StartNginxMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x31\n\nstartFlask\x12\x0e.StartFlaskMsg\x1a\x11.ServiceStatusDTO\"\x00\x12K\n\x17startDockerStatsManager\x12\x1b.StartDockerStatsManagerMsg\x1a\x11.ServiceStatusDTO\"\x00\x12W\n\x1dstartDockerStatsManagerThread\x12!.StartDockerStatsManagerThreadMsg\x1a\x11.ServiceStatusDTO\"\x00\x12?\n\x11startDockerEngine\x12\x15.StartDockerEngineMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x39\n\x0estopPostgreSQL\x12\x12.StopPostgreSQLMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x35\n\x0cstopCAdvisor\x12\x10.StopCAdvisorMsg\x1a\x11.ServiceStatusDTO\"\x00\x12=\n\x10stopNodeExporter\x12\x14.StopNodeExporterMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x33\n\x0bstopGrafana\x12\x0f.StopGrafanaMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x39\n\x0estopPrometheus\x12\x12.StopPrometheusMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x33\n\x0bstopPgAdmin\x12\x0f.StopPgAdminMsg\x1a\x11.ServiceStatusDTO\"\x00\x12/\n\tstopNginx\x12\r.StopNginxMsg\x1a\x11.ServiceStatusDTO\"\x00\x12/\n\tstopFlask\x12\r.StopFlaskMsg\x1a\x11.ServiceStatusDTO\"\x00\x12I\n\x16stopDockerStatsManager\x12\x1a.StopDockerStatsManagerMsg\x1a\x11.ServiceStatusDTO\"\x00\x12=\n\x10stopDockerEngine\x12\x14.StopDockerEngineMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x32\n\x0fgetCsleLogFiles\x12\x13.GetCsleLogFilesMsg\x1a\x08.LogsDTO\"\x00\x12\x46\n\x19getDockerStatsManagerLogs\x12\x1d.GetDockerStatsManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x36\n\x11getPrometheusLogs\x12\x15.GetPrometheusLogsMsg\x1a\x08.LogsDTO\"\x00\x12:\n\x13getNodeExporterLogs\x12\x17.GetNodeExporterLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x32\n\x0fgetCadvisorLogs\x12\x13.GetCAdvisorLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x30\n\x0egetPgAdminLogs\x12\x12.GetPgAdminLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x30\n\x0egetGrafanaLogs\x12\x12.GetGrafanaLogsMsg\x1a\x08.LogsDTO\"\x00\x12,\n\x0cgetNginxLogs\x12\x10.GetNginxLogsMsg\x1a\x08.LogsDTO\"\x00\x12.\n\rgetDockerLogs\x12\x11.GetDockerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x37\n\x12getPostrgreSQLLogs\x12\x15.GetPostgreSQLLogsMsg\x1a\x08.LogsDTO\"\x00\x12,\n\x0cgetFlaskLogs\x12\x10.GetFlaskLogsMsg\x1a\x08.LogsDTO\"\x00\x12(\n\ngetLogFile\x12\x0e.GetLogFileMsg\x1a\x08.LogsDTO\"\x00\x12T\n\x1astartContainersInExecution\x12\x1e.StartContainersInExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12j\n%attachContainersInExecutionToNetworks\x12).AttachContainersToNetworksInExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10installLibraries\x12\x14.InstallLibrariesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10\x61pplyKafkaConfig\x12\x14.ApplyKafkaConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12startSdnController\x12\x16.StartSdnControllerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12O\n\x18\x61pplyResourceConstraints\x12\x1b.ApplyResouceConstraintsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11\x63reateOvsSwitches\x12\x15.CreateOvsSwitchesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rpingExecution\x12\x11.PingExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0c\x63onfigureOvs\x12\x10.ConfigureOvsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12R\n\x19startSdnControllerMonitor\x12\x1d.StartSdnControllerMonitorMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0b\x63reateUsers\x12\x0f.CreateUsersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x15\x63reateVulnerabilities\x12\x0f.CreateVulnsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0b\x63reateFlags\x12\x0f.CreateFlagsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0e\x63reateTopology\x12\x12.CreateTopologyMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14startTrafficManagers\x12\x18.StartTrafficManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16startTrafficGenerators\x12\x1a.StartTrafficGeneratorsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15startClientPopulation\x12\x19.StartClientPopulationMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12P\n\x18startKafkaClientProducer\x12\x1c.StartKafkaClientProducerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12N\n\x17stopKafkaClientProducer\x12\x1b.StopKafkaClientProducerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartSnortIdses\x12\x13.StartSnortIdsesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12Z\n\x1dstartSnortIdsesMonitorThreads\x12!.StartSnortIdsesMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartOssecIdses\x12\x13.StartOSSECIdsesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12Z\n\x1dstartOssecIdsesMonitorThreads\x12!.StartOSSECIdsesMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstartElkStack\x12\x11.StartElkStackMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11startHostManagers\x12\x15.StartHostManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14\x61pplyFileBeatsConfig\x12\x18.ApplyFileBeatConfigsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16\x61pplyPacketBeatsConfig\x12\x1a.ApplyPacketBeatConfigsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16\x61pplyMetricBeatsConfig\x12\x1a.ApplyMetricBeatConfigsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15\x61pplyHeartBeatsConfig\x12\x19.ApplyHeartBeatConfigsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estartFilebeats\x12\x12.StartFileBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10startPacketbeats\x12\x14.StartPacketBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10startMetricbeats\x12\x14.StartMetricBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartHeartbeats\x12\x13.StartHeartBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12X\n\x1cstopAllExecutionsOfEmulation\x12 .StopAllExecutionsOfEmulationMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstopExecution\x12\x11.StopExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11stopAllExecutions\x12\x15.StopAllExecutionsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12\x63leanAllExecutions\x12\x16.CleanAllExecutionsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12Z\n\x1d\x63leanAllExecutionsOfEmulation\x12!.CleanAllExecutionsOfEmulationMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0e\x63leanExecution\x12\x12.CleanExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x46\n\x13startTrafficManager\x12\x17.StartTrafficManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x45\n\x12stopTrafficManager\x12\x17.StartTrafficManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12G\n\x13stopTrafficManagers\x12\x18.StartTrafficManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12startClientManager\x12\x16.StartClientManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14stopClientPopulation\x12\x18.StopClientPopulationMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11stopClientManager\x12\x15.StopClientManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x43\n\x13getNumActiveClients\x12\x17.GetNumActiveClientsMsg\x1a\x11.GetNumClientsDTO\"\x00\x12J\n\x15startTrafficGenerator\x12\x19.StartTrafficGeneratorMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15stopTrafficGenerators\x12\x19.StopTrafficGeneratorsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14stopTrafficGenerator\x12\x18.StopTrafficGeneratorMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x15getClientManagersInfo\x12\x19.GetClientManagersInfoMsg\x1a\x16.ClientManagersInfoDTO\"\x00\x12N\n\x16getTrafficManagersInfo\x12\x1a.GetTrafficManagersInfoMsg\x1a\x16.TrafficManagerInfoDTO\"\x00\x12P\n\x18stopAllRunningContainers\x12\x1c.StopAllRunningContainersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstopContainer\x12\x11.StopContainerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1aremoveAllStoppedContainers\x12\x1e.RemoveAllStoppedContainersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fremoveContainer\x12\x13.RemoveContainerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12P\n\x18removeAllContainerImages\x12\x1c.RemoveAllContainerImagesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14removeContainerImage\x12\x18.RemoveContainerImageMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12K\n\x16listAllContainerImages\x12\x1a.ListAllContainerImagesMsg\x1a\x13.ContainerImagesDTO\"\x00\x12H\n\x15listAllDockerNetworks\x12\x19.ListAllDockerNetworksMsg\x1a\x12.DockerNetworksDTO\"\x00\x12R\n\x19startAllStoppedContainers\x12\x1d.StartAllStoppedContainersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estartContainer\x12\x12.StartContainerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12Q\n\x18listAllRunningContainers\x12\x1c.ListAllRunningContainersMsg\x1a\x15.RunningContainersDTO\"\x00\x12Q\n\x18listAllRunningEmulations\x12\x1c.ListAllRunningEmulationsMsg\x1a\x15.RunningEmulationsDTO\"\x00\x12Q\n\x18listAllStoppedContainers\x12\x1c.ListAllStoppedContainersMsg\x1a\x15.StoppedContainersDTO\"\x00\x12N\n\x17\x63reateEmulationNetworks\x12\x1b.CreateEmulationNetworksMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12X\n\x1cstopDockerStatsManagerThread\x12 .StopDockerStatsManagerThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12^\n\x1bgetDockerStatsManagerStatus\x12\x1f.GetDockerStatsManagerStatusMsg\x1a\x1c.DockerStatsMonitorStatusDTO\"\x00\x12H\n\x14removeDockerNetworks\x12\x18.RemoveDockerNetworksMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12N\n\x17removeAllDockerNetworks\x12\x1b.RemoveAllDockerNetworksMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12[\n\x1agetDockerStatsManagersInfo\x12\x1e.GetDockerStatsManagersInfoMsg\x1a\x1b.DockerStatsManagersInfoDTO\"\x00\x12>\n\x0fstartElkManager\x12\x13.StartElkManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopElkManager\x12\x12.StopElkManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0cgetElkStatus\x12\x15.GetElkStackStatusMsg\x1a\r.ElkStatusDTO\"\x00\x12\x38\n\x0cstopElkStack\x12\x10.StopElkStackMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x0cstartElastic\x12\x17.StartElasticServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12=\n\x0bstopElastic\x12\x16.StopElasticServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12=\n\x0bstartKibana\x12\x16.StartKibanaServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12;\n\nstopKibana\x12\x15.StopKibanaServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x41\n\rstartLogstash\x12\x18.StartLogstashServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x0cstopLogstash\x12\x17.StopLogstashServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x43\n\x12getElkManagersInfo\x12\x16.GetElkManagersInfoMsg\x1a\x13.ElkManagersInfoDTO\"\x00\x12T\n\x1astartContainersOfExecution\x12\x1e.StartContainersOfExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0crunContainer\x12\x10.RunContainerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12R\n\x19stopContainersOfExecution\x12\x1d.StopContainersOfExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10startHostManager\x12\x14.StartHostManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10stopHostManagers\x12\x14.StopHostManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstopHostManager\x12\x13.StopHostManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstopFilebeats\x12\x11.StopFilebeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstopPacketbeats\x12\x13.StopPacketbeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstopMetricbeats\x12\x13.StopMetricbeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopHeartbeats\x12\x12.StopHeartbeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12N\n\x17startHostMonitorThreads\x12\x1b.StartHostMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16startHostMonitorThread\x12\x1a.StartHostMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12;\n\rstartFilebeat\x12\x12.StartFileBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x0fstartPacketbeat\x12\x14.StartPacketBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x0fstartMetricbeat\x12\x14.StartMetricBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12=\n\x0estartHeartbeat\x12\x13.StartHeartBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0cstopFilebeat\x12\x10.StopFileBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopPacketbeat\x12\x12.StopPacketBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopMetricbeat\x12\x12.StopMetricBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstopHeartbeat\x12\x11.StopHeartBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x46\n\x13\x61pplyFileBeatConfig\x12\x17.ApplyFileBeatConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15\x61pplyPacketBeatConfig\x12\x19.ApplyPacketBeatConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15\x61pplyMetricBeatConfig\x12\x19.ApplyMetricBeatConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14\x61pplyHeartBeatConfig\x12\x18.ApplyHeartBeatConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12]\n\x1dgetHostMonitorThreadsStatuses\x12!.GetHostMonitorThreadsStatusesMsg\x1a\x17.HostManagerStatusesDTO\"\x00\x12\x46\n\x13getHostManagersInfo\x12\x17.GetHostManagersInfoMsg\x1a\x14.HostManagersInfoDTO\"\x00\x12@\n\x10stopKafkaManager\x12\x14.StopKafkaManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11startKafkaManager\x12\x15.StartKafkaManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11\x63reateKafkaTopics\x12\x15.CreateKafkaTopicsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0egetKafkaStatus\x12\x19.GetKafkaManagerStatusMsg\x1a\x0f.KafkaStatusDTO\"\x00\x12>\n\x0fstopKafkaServer\x12\x13.StopKafkaServerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x10startKafkaServer\x12\x13.StopKafkaServerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12I\n\x14getKafkaManagersInfo\x12\x18.GetKafkaManagersInfoMsg\x1a\x15.KafkaManagersInfoDTO\"\x00\x12<\n\x0estopOSSECIDSes\x12\x12.StopOSSECIDSesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartOSSECIDSes\x12\x13.StartOSSECIDSesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0cstopOSSECIDS\x12\x10.StopOSSECIDSMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstartOSSECIDS\x12\x11.StartOSSECIDSMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12G\n\x15startOSSECIDSManagers\x12\x16.StartOSSECIDSManagers\x1a\x14.OperationOutcomeDTO\"\x00\x12\x45\n\x14stopOSSECIDSManagers\x12\x15.StopOSSECIDSManagers\x1a\x14.OperationOutcomeDTO\"\x00\x12\x45\n\x14startOSSECIDSManager\x12\x15.StartOSSECIDSManager\x1a\x14.OperationOutcomeDTO\"\x00\x12\x43\n\x13stopOSSECIDSManager\x12\x14.StopOSSECIDSManager\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1astartOSSECIDSMonitorThread\x12\x1e.StartOSSECIDSMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12R\n\x19stopOSSECIDSMonitorThread\x12\x1d.StopOSSECIDSMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1astopOSSECIDSMonitorThreads\x12\x1e.StopOSSECIDSMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12m\n getOSSECIDSMonitorThreadStatuses\x12$.GetOSSECIDSMonitorThreadStatusesMsg\x1a!.OSSECIdsMonitorThreadStatusesDTO\"\x00\x12R\n\x17getOSSECIdsManagersInfo\x12\x1b.GetOSSECIDSManagersInfoMsg\x1a\x18.OSSECIdsManagersInfoDTO\"\x00\x12>\n\x0fstartRyuManager\x12\x13.StartRyuManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopRyuManager\x12\x12.StopRyuManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x0cgetRyuStatus\x12\x17.GetRyuServiceStatusMsg\x1a\x14.RyuManagerStatusDTO\"\x00\x12\x37\n\x08startRyu\x12\x13.StartRyuServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x35\n\x07stopRyu\x12\x12.StopRyuServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x43\n\x12getRyuManagersInfo\x12\x16.GetRyuManagersInfoMsg\x1a\x13.RyuManagersInfoDTO\"\x00\x12<\n\x0estopSnortIdses\x12\x12.StopSnortIdsesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12X\n\x1cstopSnortIdsesMonitorThreads\x12 .StopSnortIdsesMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x35\n\x0cstopSnortIds\x12\r.StopSnortMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12R\n\x19stopSnortIdsMonitorThread\x12\x1d.StopSnortIdsMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x37\n\rstartSnortIds\x12\x0e.StartSnortMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12V\n\x1bstartSnortIdsMonitorThreads\x12\x1f.StartSnortIdsMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1astartSnortIdsMonitorThread\x12\x1e.StartSnortIdsMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15startSnortIdsManagers\x12\x19.StartSnortIdsManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14stopSnortIdsManagers\x12\x18.StopSnortIdsManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14startSnortIdsManager\x12\x18.StartSnortIdsManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x46\n\x13stopSnortIdsManager\x12\x17.StopSnortIdsManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1astopSnortIdsMonitorThreads\x12\x1e.StopSnortIdsMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12m\n getSnortIdsMonitorThreadStatuses\x12$.GetSnortIdsMonitorThreadStatusesMsg\x1a!.SnortIdsMonitorThreadStatusesDTO\"\x00\x12R\n\x17getSnortIdsManagersInfo\x12\x1b.GetSnortIdsManagersInfoMsg\x1a\x18.SnortIdsManagersInfoDTO\"\x00\x12=\n\x10getExecutionInfo\x12\x14.GetExecutionInfoMsg\x1a\x11.ExecutionInfoDTO\"\x00\x12?\n\x11listKibanaTunnels\x12\x15.ListKibanaTunnelsMsg\x1a\x11.KibanaTunnelsDTO\"\x00\x12\x44\n\x12\x63reateKibanaTunnel\x12\x16.CreateKibanaTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0elistRyuTunnels\x12\x12.ListRyuTunnelsMsg\x1a\x0e.RyuTunnelsDTO\"\x00\x12\x41\n\x0f\x63reateRyuTunnel\x12\x16.CreateKibanaTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12removeKibanaTunnel\x12\x16.RemoveKibanaTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fremoveRyuTunnel\x12\x13.RemoveRyuTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16stopHostMonitorThreads\x12\x1a.StopHostMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15stopHostMonitorThread\x12\x19.StopHostMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x0fstartRyuMonitor\x12\x19.StartRyuMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x0estopRyuMonitor\x12\x18.StopRyuMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x14getRyuControllerLogs\x12\x18.GetRyuControllerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x36\n\x11getRyuManagerLogs\x12\x15.GetRyuManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12(\n\ngetElkLogs\x12\x0e.GetElkLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x36\n\x11getElkManagerLogs\x12\x15.GetElkManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12>\n\x15getTrafficManagerLogs\x12\x19.GetTrafficManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x38\n\x12getHostManagerLogs\x12\x16.GetHostManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x32\n\x0fgetOSSECIdsLogs\x12\x13.GetOSSECIdsLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x43\n\x19getOSSECIdsManagerLogsMsg\x12\x1a.GetOSSECIdsManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x32\n\x0fgetSnortIdsLogs\x12\x13.GetSnortIdsLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x43\n\x19getSnortIdsManagerLogsMsg\x12\x1a.GetSnortIdsManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12,\n\x0cgetKafkaLogs\x12\x10.GetKafkaLogsMsg\x1a\x08.LogsDTO\"\x00\x12:\n\x13getKafkaManagerLogs\x12\x17.GetKafkaManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12?\n\x17getClientManagerLogsMsg\x12\x18.GetClientManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x34\n\x10getContainerLogs\x12\x14.GetContainerLogsMsg\x1a\x08.LogsDTO\"\x00\x12>\n\x15getClusterManagerLogs\x12\x19.GetClusterManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12^\n\x1agetExecutionTimeSeriesData\x12\x1e.GetExecutionTimeSeriesDataMsg\x1a\x1e.EmulationMetricsTimeSeriesDTO\"\x00\x12\x42\n\x11startSparkServers\x12\x15.StartSparkServersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10stopSparkServers\x12\x14.StopSparkServersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10startSparkServer\x12\x14.StartSparkServerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstopSparkServer\x12\x13.StopSparkServerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x30\n\x08\x63heckPid\x12\x0c.CheckPidMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12.\n\x07stopPid\x12\x0b.StopPidMsg\x1a\x14.OperationOutcomeDTO\"\x00\x62\x06proto3')



_STOPPIDMSG = DESCRIPTOR.message_types_by_name['StopPidMsg']
_CHECKPIDMSG = DESCRIPTOR.message_types_by_name['CheckPidMsg']
_STARTSPARKSERVERMSG = DESCRIPTOR.message_types_by_name['StartSparkServerMsg']
_STOPSPARKSERVERMSG = DESCRIPTOR.message_types_by_name['StopSparkServerMsg']
_STARTSPARKSERVERSMSG = DESCRIPTOR.message_types_by_name['StartSparkServersMsg']
_STOPSPARKSERVERSMSG = DESCRIPTOR.message_types_by_name['StopSparkServersMsg']
_GETEXECUTIONTIMESERIESDATAMSG = DESCRIPTOR.message_types_by_name['GetExecutionTimeSeriesDataMsg']
_EMULATIONMETRICSTIMESERIESDTO = DESCRIPTOR.message_types_by_name['EmulationMetricsTimeSeriesDTO']
_AVGPORTSTATISTICDICT = DESCRIPTOR.message_types_by_name['AvgPortStatisticDict']
_AGGFLOWSTATISTICDICT = DESCRIPTOR.message_types_by_name['AggFlowStatisticDict']
_AVGFLOWSTATISTICDICT = DESCRIPTOR.message_types_by_name['AvgFlowStatisticDict']
_PORTSTATISTICDICT = DESCRIPTOR.message_types_by_name['PortStatisticDict']
_FLOWSTATISTICDICT = DESCRIPTOR.message_types_by_name['FlowStatisticDict']
_OSSECIDSALERTCOUNTERSDICT = DESCRIPTOR.message_types_by_name['OSSECIdsAlertCountersDict']
_HOSTMETRICSDICT = DESCRIPTOR.message_types_by_name['HostMetricsDict']
_DOCKERSTATSDICT = DESCRIPTOR.message_types_by_name['DockerStatsDict']
_AVGPORTSTATISTICDTO = DESCRIPTOR.message_types_by_name['AvgPortStatisticDTO']
_AVGFLOWSTATISTICDTO = DESCRIPTOR.message_types_by_name['AvgFlowStatisticDTO']
_AGGFLOWSTATISTICDTO = DESCRIPTOR.message_types_by_name['AggFlowStatisticDTO']
_PORTSTATISTICDTO = DESCRIPTOR.message_types_by_name['PortStatisticDTO']
_FLOWSTATISTICDTO = DESCRIPTOR.message_types_by_name['FlowStatisticDTO']
_OSSECIDSALERTCOUNTERSDTO = DESCRIPTOR.message_types_by_name['OSSECIdsAlertCountersDTO']
_SNORTIDSALERTCOUNTERSDTO = DESCRIPTOR.message_types_by_name['SnortIdsAlertCountersDTO']
_SNORTIDSIPALERTCOUNTERSDICT = DESCRIPTOR.message_types_by_name['SnortIdsIpAlertCountersDict']
_SNORTIDSALERTCOUNTERSDICT = DESCRIPTOR.message_types_by_name['SnortIdsAlertCountersDict']
_SNORTIDSRULECOUNTERSDICT = DESCRIPTOR.message_types_by_name['SnortIdsRuleCountersDict']
_SNORTIDSIPALERTCOUNTERSDTO = DESCRIPTOR.message_types_by_name['SnortIdsIpAlertCountersDTO']
_SNORTIDSRULECOUNTERSDTO = DESCRIPTOR.message_types_by_name['SnortIdsRuleCountersDTO']
_EMULATIONATTACKERACTIONDTO = DESCRIPTOR.message_types_by_name['EmulationAttackerActionDTO']
_EMULATIONDEFENDERACTIONDTO = DESCRIPTOR.message_types_by_name['EmulationDefenderActionDTO']
_HOSTMETRICSDATADTO = DESCRIPTOR.message_types_by_name['HostMetricsDataDTO']
_DOCKERSTATSDTO = DESCRIPTOR.message_types_by_name['DockerStatsDTO']
_CLIENTPOPULATIONMETRICSDTO = DESCRIPTOR.message_types_by_name['ClientPopulationMetricsDTO']
_GETCLUSTERMANAGERLOGSMSG = DESCRIPTOR.message_types_by_name['GetClusterManagerLogsMsg']
_GETCONTAINERLOGSMSG = DESCRIPTOR.message_types_by_name['GetContainerLogsMsg']
_GETCLIENTMANAGERLOGSMSG = DESCRIPTOR.message_types_by_name['GetClientManagerLogsMsg']
_GETKAFKAMANAGERLOGSMSG = DESCRIPTOR.message_types_by_name['GetKafkaManagerLogsMsg']
_GETKAFKALOGSMSG = DESCRIPTOR.message_types_by_name['GetKafkaLogsMsg']
_GETSNORTIDSLOGSMSG = DESCRIPTOR.message_types_by_name['GetSnortIdsLogsMsg']
_GETSNORTIDSMANAGERLOGSMSG = DESCRIPTOR.message_types_by_name['GetSnortIdsManagerLogsMsg']
_GETOSSECIDSMANAGERLOGSMSG = DESCRIPTOR.message_types_by_name['GetOSSECIdsManagerLogsMsg']
_GETOSSECIDSLOGSMSG = DESCRIPTOR.message_types_by_name['GetOSSECIdsLogsMsg']
_GETHOSTMANAGERLOGSMSG = DESCRIPTOR.message_types_by_name['GetHostManagerLogsMsg']
_GETTRAFFICMANAGERLOGSMSG = DESCRIPTOR.message_types_by_name['GetTrafficManagerLogsMsg']
_GETELKMANAGERLOGSMSG = DESCRIPTOR.message_types_by_name['GetElkManagerLogsMsg']
_GETELKLOGSMSG = DESCRIPTOR.message_types_by_name['GetElkLogsMsg']
_GETRYUMANAGERLOGSMSG = DESCRIPTOR.message_types_by_name['GetRyuManagerLogsMsg']
_GETRYUCONTROLLERLOGSMSG = DESCRIPTOR.message_types_by_name['GetRyuControllerLogsMsg']
_STOPRYUMONITORTHREADMSG = DESCRIPTOR.message_types_by_name['StopRyuMonitorThreadMsg']
_STARTRYUMONITORTHREADMSG = DESCRIPTOR.message_types_by_name['StartRyuMonitorThreadMsg']
_STOPHOSTMONITORTHREADSMSG = DESCRIPTOR.message_types_by_name['StopHostMonitorThreadsMsg']
_STOPHOSTMONITORTHREADMSG = DESCRIPTOR.message_types_by_name['StopHostMonitorThreadMsg']
_REMOVEKIBANATUNNELMSG = DESCRIPTOR.message_types_by_name['RemoveKibanaTunnelMsg']
_CREATEKIBANATUNNELMSG = DESCRIPTOR.message_types_by_name['CreateKibanaTunnelMsg']
_LISTKIBANATUNNELSMSG = DESCRIPTOR.message_types_by_name['ListKibanaTunnelsMsg']
_KIBANATUNNELSDTO = DESCRIPTOR.message_types_by_name['KibanaTunnelsDTO']
_KIBANATUNNELDTO = DESCRIPTOR.message_types_by_name['KibanaTunnelDTO']
_REMOVERYUTUNNELMSG = DESCRIPTOR.message_types_by_name['RemoveRyuTunnelMsg']
_CREATERYUTUNNELMSG = DESCRIPTOR.message_types_by_name['CreateRyuTunnelMsg']
_LISTRYUTUNNELSMSG = DESCRIPTOR.message_types_by_name['ListRyuTunnelsMsg']
_RYUTUNNELSDTO = DESCRIPTOR.message_types_by_name['RyuTunnelsDTO']
_RYUTUNNELDTO = DESCRIPTOR.message_types_by_name['RyuTunnelDTO']
_SNORTIDSMONITORTHREADSTATUSESDTO = DESCRIPTOR.message_types_by_name['SnortIdsMonitorThreadStatusesDTO']
_GETSNORTIDSMANAGERSINFOMSG = DESCRIPTOR.message_types_by_name['GetSnortIdsManagersInfoMsg']
_GETSNORTIDSMONITORTHREADSTATUSESMSG = DESCRIPTOR.message_types_by_name['GetSnortIdsMonitorThreadStatusesMsg']
_STOPSNORTIDSMONITORTHREADSMSG = DESCRIPTOR.message_types_by_name['StopSnortIdsMonitorThreadsMsg']
_STOPSNORTIDSMANAGERMSG = DESCRIPTOR.message_types_by_name['StopSnortIdsManagerMsg']
_STARTSNORTIDSMANAGERMSG = DESCRIPTOR.message_types_by_name['StartSnortIdsManagerMsg']
_STOPSNORTIDSMANAGERSMSG = DESCRIPTOR.message_types_by_name['StopSnortIdsManagersMsg']
_STARTSNORTIDSMANAGERSMSG = DESCRIPTOR.message_types_by_name['StartSnortIdsManagersMsg']
_STARTSNORTMSG = DESCRIPTOR.message_types_by_name['StartSnortMsg']
_STARTSNORTIDSMONITORTHREADMSG = DESCRIPTOR.message_types_by_name['StartSnortIdsMonitorThreadMsg']
_STARTSNORTIDSMONITORTHREADSMSG = DESCRIPTOR.message_types_by_name['StartSnortIdsMonitorThreadsMsg']
_STOPSNORTMSG = DESCRIPTOR.message_types_by_name['StopSnortMsg']
_STOPSNORTIDSMONITORTHREADMSG = DESCRIPTOR.message_types_by_name['StopSnortIdsMonitorThreadMsg']
_STOPSNORTIDSESMSG = DESCRIPTOR.message_types_by_name['StopSnortIdsesMsg']
_STOPSNORTIDSESMONITORTHREADSMSG = DESCRIPTOR.message_types_by_name['StopSnortIdsesMonitorThreadsMsg']
_GETRYUMANAGERSINFOMSG = DESCRIPTOR.message_types_by_name['GetRyuManagersInfoMsg']
_STOPRYUMONITORSERVICEMSG = DESCRIPTOR.message_types_by_name['StopRyuMonitorServiceMsg']
_STARTRYUMONITORSERVICEMSG = DESCRIPTOR.message_types_by_name['StartRyuMonitorServiceMsg']
_STOPRYUSERVICEMSG = DESCRIPTOR.message_types_by_name['StopRyuServiceMsg']
_STARTRYUSERVICEMSG = DESCRIPTOR.message_types_by_name['StartRyuServiceMsg']
_GETRYUSERVICESTATUSMSG = DESCRIPTOR.message_types_by_name['GetRyuServiceStatusMsg']
_STOPRYUMANAGERMSG = DESCRIPTOR.message_types_by_name['StopRyuManagerMsg']
_STARTRYUMANAGERMSG = DESCRIPTOR.message_types_by_name['StartRyuManagerMsg']
_GETOSSECIDSMANAGERSINFOMSG = DESCRIPTOR.message_types_by_name['GetOSSECIDSManagersInfoMsg']
_OSSECIDSMONITORTHREADSTATUSESDTO = DESCRIPTOR.message_types_by_name['OSSECIdsMonitorThreadStatusesDTO']
_GETOSSECIDSMONITORTHREADSTATUSESMSG = DESCRIPTOR.message_types_by_name['GetOSSECIDSMonitorThreadStatusesMsg']
_STOPOSSECIDSMONITORTHREADSMSG = DESCRIPTOR.message_types_by_name['StopOSSECIDSMonitorThreadsMsg']
_STOPOSSECIDSMONITORTHREADMSG = DESCRIPTOR.message_types_by_name['StopOSSECIDSMonitorThreadMsg']
_STARTOSSECIDSMONITORTHREADMSG = DESCRIPTOR.message_types_by_name['StartOSSECIDSMonitorThreadMsg']
_STOPOSSECIDSMANAGER = DESCRIPTOR.message_types_by_name['StopOSSECIDSManager']
_STARTOSSECIDSMANAGER = DESCRIPTOR.message_types_by_name['StartOSSECIDSManager']
_STOPOSSECIDSMANAGERS = DESCRIPTOR.message_types_by_name['StopOSSECIDSManagers']
_STARTOSSECIDSMANAGERS = DESCRIPTOR.message_types_by_name['StartOSSECIDSManagers']
_STARTOSSECIDSMSG = DESCRIPTOR.message_types_by_name['StartOSSECIDSMsg']
_STOPOSSECIDSMSG = DESCRIPTOR.message_types_by_name['StopOSSECIDSMsg']
_STARTOSSECIDSESMSG = DESCRIPTOR.message_types_by_name['StartOSSECIDSesMsg']
_STOPOSSECIDSESMSG = DESCRIPTOR.message_types_by_name['StopOSSECIDSesMsg']
_GETKAFKAMANAGERSINFOMSG = DESCRIPTOR.message_types_by_name['GetKafkaManagersInfoMsg']
_STARTKAFKASERVERMSG = DESCRIPTOR.message_types_by_name['StartKafkaServerMsg']
_STOPKAFKASERVERMSG = DESCRIPTOR.message_types_by_name['StopKafkaServerMsg']
_GETKAFKAMANAGERSTATUSMSG = DESCRIPTOR.message_types_by_name['GetKafkaManagerStatusMsg']
_CREATEKAFKATOPICSMSG = DESCRIPTOR.message_types_by_name['CreateKafkaTopicsMsg']
_STOPKAFKAMANAGERMSG = DESCRIPTOR.message_types_by_name['StopKafkaManagerMsg']
_STARTKAFKAMANAGERMSG = DESCRIPTOR.message_types_by_name['StartKafkaManagerMsg']
_GETHOSTMANAGERSINFOMSG = DESCRIPTOR.message_types_by_name['GetHostManagersInfoMsg']
_GETHOSTMONITORTHREADSSTATUSESMSG = DESCRIPTOR.message_types_by_name['GetHostMonitorThreadsStatusesMsg']
_APPLYFILEBEATCONFIGMSG = DESCRIPTOR.message_types_by_name['ApplyFileBeatConfigMsg']
_APPLYPACKETBEATCONFIGMSG = DESCRIPTOR.message_types_by_name['ApplyPacketBeatConfigMsg']
_APPLYMETRICBEATCONFIGMSG = DESCRIPTOR.message_types_by_name['ApplyMetricBeatConfigMsg']
_APPLYHEARTBEATCONFIGMSG = DESCRIPTOR.message_types_by_name['ApplyHeartBeatConfigMsg']
_STOPFILEBEATMSG = DESCRIPTOR.message_types_by_name['StopFileBeatMsg']
_STOPPACKETBEATMSG = DESCRIPTOR.message_types_by_name['StopPacketBeatMsg']
_STOPMETRICBEATMSG = DESCRIPTOR.message_types_by_name['StopMetricBeatMsg']
_STOPHEARTBEATMSG = DESCRIPTOR.message_types_by_name['StopHeartBeatMsg']
_STARTFILEBEATMSG = DESCRIPTOR.message_types_by_name['StartFileBeatMsg']
_STARTPACKETBEATMSG = DESCRIPTOR.message_types_by_name['StartPacketBeatMsg']
_STARTMETRICBEATMSG = DESCRIPTOR.message_types_by_name['StartMetricBeatMsg']
_STARTHEARTBEATMSG = DESCRIPTOR.message_types_by_name['StartHeartBeatMsg']
_STARTHOSTMONITORTHREADMSG = DESCRIPTOR.message_types_by_name['StartHostMonitorThreadMsg']
_STOPHEARTBEATSMSG = DESCRIPTOR.message_types_by_name['StopHeartbeatsMsg']
_STOPPACKETBEATSMSG = DESCRIPTOR.message_types_by_name['StopPacketbeatsMsg']
_STOPFILEBEATSMSG = DESCRIPTOR.message_types_by_name['StopFilebeatsMsg']
_STOPMETRICBEATSMSG = DESCRIPTOR.message_types_by_name['StopMetricbeatsMsg']
_STARTHOSTMONITORTHREADSMSG = DESCRIPTOR.message_types_by_name['StartHostMonitorThreadsMsg']
_STOPHOSTMANAGERMSG = DESCRIPTOR.message_types_by_name['StopHostManagerMsg']
_STARTHOSTMANAGERMSG = DESCRIPTOR.message_types_by_name['StartHostManagerMsg']
_STOPHOSTMANAGERSMSG = DESCRIPTOR.message_types_by_name['StopHostManagersMsg']
_EXECUTIONINFODTO = DESCRIPTOR.message_types_by_name['ExecutionInfoDTO']
_RYUMANAGERSINFODTO = DESCRIPTOR.message_types_by_name['RyuManagersInfoDTO']
_RYUMANAGERSTATUSDTO = DESCRIPTOR.message_types_by_name['RyuManagerStatusDTO']
_HOSTMANAGERSINFODTO = DESCRIPTOR.message_types_by_name['HostManagersInfoDTO']
_HOSTMANAGERSTATUSESDTO = DESCRIPTOR.message_types_by_name['HostManagerStatusesDTO']
_HOSTMANAGERSTATUSDTO = DESCRIPTOR.message_types_by_name['HostManagerStatusDTO']
_KAFKAMANAGERSINFODTO = DESCRIPTOR.message_types_by_name['KafkaManagersInfoDTO']
_KAFKASTATUSDTO = DESCRIPTOR.message_types_by_name['KafkaStatusDTO']
_OSSECIDSMANAGERSINFODTO = DESCRIPTOR.message_types_by_name['OSSECIdsManagersInfoDTO']
_OSSECIDSSTATUSDTO = DESCRIPTOR.message_types_by_name['OSSECIdsStatusDTO']
_SNORTIDSMANAGERSINFODTO = DESCRIPTOR.message_types_by_name['SnortIdsManagersInfoDTO']
_SNORTIDSSTATUSDTO = DESCRIPTOR.message_types_by_name['SnortIdsStatusDTO']
_GETEXECUTIONINFOMSG = DESCRIPTOR.message_types_by_name['GetExecutionInfoMsg']
_STOPCONTAINERSOFEXECUTIONMSG = DESCRIPTOR.message_types_by_name['StopContainersOfExecutionMsg']
_RUNCONTAINERMSG = DESCRIPTOR.message_types_by_name['RunContainerMsg']
_STARTCONTAINERSOFEXECUTIONMSG = DESCRIPTOR.message_types_by_name['StartContainersOfExecutionMsg']
_GETELKMANAGERSINFOMSG = DESCRIPTOR.message_types_by_name['GetElkManagersInfoMsg']
_ELKMANAGERSINFODTO = DESCRIPTOR.message_types_by_name['ElkManagersInfoDTO']
_STOPLOGSTASHSERVICEMSG = DESCRIPTOR.message_types_by_name['StopLogstashServiceMsg']
_STARTLOGSTASHSERVICEMSG = DESCRIPTOR.message_types_by_name['StartLogstashServiceMsg']
_STOPKIBANASERVICEMSG = DESCRIPTOR.message_types_by_name['StopKibanaServiceMsg']
_STARTKIBANASERVICEMSG = DESCRIPTOR.message_types_by_name['StartKibanaServiceMsg']
_STOPELASTICSERVICEMSG = DESCRIPTOR.message_types_by_name['StopElasticServiceMsg']
_STARTELASTICSERVICEMSG = DESCRIPTOR.message_types_by_name['StartElasticServiceMsg']
_STOPELKSTACKMSG = DESCRIPTOR.message_types_by_name['StopElkStackMsg']
_ELKSTATUSDTO = DESCRIPTOR.message_types_by_name['ElkStatusDTO']
_GETELKSTACKSTATUSMSG = DESCRIPTOR.message_types_by_name['GetElkStackStatusMsg']
_STOPELKMANAGERMSG = DESCRIPTOR.message_types_by_name['StopElkManagerMsg']
_STARTELKMANAGERMSG = DESCRIPTOR.message_types_by_name['StartElkManagerMsg']
_GETDOCKERSTATSMANAGERSINFOMSG = DESCRIPTOR.message_types_by_name['GetDockerStatsManagersInfoMsg']
_DOCKERSTATSMANAGERSINFODTO = DESCRIPTOR.message_types_by_name['DockerStatsManagersInfoDTO']
_REMOVEALLDOCKERNETWORKSMSG = DESCRIPTOR.message_types_by_name['RemoveAllDockerNetworksMsg']
_REMOVEDOCKERNETWORKSMSG = DESCRIPTOR.message_types_by_name['RemoveDockerNetworksMsg']
_DOCKERSTATSMONITORSTATUSDTO = DESCRIPTOR.message_types_by_name['DockerStatsMonitorStatusDTO']
_GETDOCKERSTATSMANAGERSTATUSMSG = DESCRIPTOR.message_types_by_name['GetDockerStatsManagerStatusMsg']
_STOPDOCKERSTATSMANAGERTHREADMSG = DESCRIPTOR.message_types_by_name['StopDockerStatsManagerThreadMsg']
_CREATEEMULATIONNETWORKSMSG = DESCRIPTOR.message_types_by_name['CreateEmulationNetworksMsg']
_LISTALLSTOPPEDCONTAINERSMSG = DESCRIPTOR.message_types_by_name['ListAllStoppedContainersMsg']
_STOPPEDCONTAINERSDTO = DESCRIPTOR.message_types_by_name['StoppedContainersDTO']
_LISTALLRUNNINGEMULATIONSMSG = DESCRIPTOR.message_types_by_name['ListAllRunningEmulationsMsg']
_RUNNINGEMULATIONSDTO = DESCRIPTOR.message_types_by_name['RunningEmulationsDTO']
_LISTALLRUNNINGCONTAINERSMSG = DESCRIPTOR.message_types_by_name['ListAllRunningContainersMsg']
_RUNNINGCONTAINERSDTO = DESCRIPTOR.message_types_by_name['RunningContainersDTO']
_DOCKERCONTAINERDTO = DESCRIPTOR.message_types_by_name['DockerContainerDTO']
_STARTCONTAINERMSG = DESCRIPTOR.message_types_by_name['StartContainerMsg']
_STARTALLSTOPPEDCONTAINERSMSG = DESCRIPTOR.message_types_by_name['StartAllStoppedContainersMsg']
_LISTALLDOCKERNETWORKSMSG = DESCRIPTOR.message_types_by_name['ListAllDockerNetworksMsg']
_DOCKERNETWORKSDTO = DESCRIPTOR.message_types_by_name['DockerNetworksDTO']
_CONTAINERIMAGESDTO = DESCRIPTOR.message_types_by_name['ContainerImagesDTO']
_CONTAINERIMAGEDTO = DESCRIPTOR.message_types_by_name['ContainerImageDTO']
_LISTALLCONTAINERIMAGESMSG = DESCRIPTOR.message_types_by_name['ListAllContainerImagesMsg']
_REMOVECONTAINERIMAGEMSG = DESCRIPTOR.message_types_by_name['RemoveContainerImageMsg']
_REMOVEALLCONTAINERIMAGESMSG = DESCRIPTOR.message_types_by_name['RemoveAllContainerImagesMsg']
_REMOVEALLSTOPPEDCONTAINERSMSG = DESCRIPTOR.message_types_by_name['RemoveAllStoppedContainersMsg']
_REMOVECONTAINERMSG = DESCRIPTOR.message_types_by_name['RemoveContainerMsg']
_STOPCONTAINERMSG = DESCRIPTOR.message_types_by_name['StopContainerMsg']
_STOPALLRUNNINGCONTAINERSMSG = DESCRIPTOR.message_types_by_name['StopAllRunningContainersMsg']
_GETTRAFFICMANAGERSINFOMSG = DESCRIPTOR.message_types_by_name['GetTrafficManagersInfoMsg']
_TRAFFICMANAGERSINFODTO = DESCRIPTOR.message_types_by_name['TrafficManagersInfoDTO']
_TRAFFICMANAGERINFODTO = DESCRIPTOR.message_types_by_name['TrafficManagerInfoDTO']
_CLIENTMANAGERSINFODTO = DESCRIPTOR.message_types_by_name['ClientManagersInfoDTO']
_GETCLIENTMANAGERSINFOMSG = DESCRIPTOR.message_types_by_name['GetClientManagersInfoMsg']
_STARTTRAFFICGENERATORMSG = DESCRIPTOR.message_types_by_name['StartTrafficGeneratorMsg']
_STOPTRAFFICGENERATORMSG = DESCRIPTOR.message_types_by_name['StopTrafficGeneratorMsg']
_STOPTRAFFICGENERATORSMSG = DESCRIPTOR.message_types_by_name['StopTrafficGeneratorsMsg']
_GETNUMCLIENTSDTO = DESCRIPTOR.message_types_by_name['GetNumClientsDTO']
_GETNUMACTIVECLIENTSMSG = DESCRIPTOR.message_types_by_name['GetNumActiveClientsMsg']
_STOPCLIENTPOPULATIONMSG = DESCRIPTOR.message_types_by_name['StopClientPopulationMsg']
_STOPCLIENTMANAGERMSG = DESCRIPTOR.message_types_by_name['StopClientManagerMsg']
_STARTCLIENTMANAGERMSG = DESCRIPTOR.message_types_by_name['StartClientManagerMsg']
_STOPTRAFFICMANAGERSMSG = DESCRIPTOR.message_types_by_name['StopTrafficManagersMsg']
_STOPTRAFFICMANAGERMSG = DESCRIPTOR.message_types_by_name['StopTrafficManagerMsg']
_STARTTRAFFICMANAGERMSG = DESCRIPTOR.message_types_by_name['StartTrafficManagerMsg']
_CLEANALLEXECUTIONSMSG = DESCRIPTOR.message_types_by_name['CleanAllExecutionsMsg']
_STOPALLEXECUTIONSMSG = DESCRIPTOR.message_types_by_name['StopAllExecutionsMsg']
_STOPEXECUTIONMSG = DESCRIPTOR.message_types_by_name['StopExecutionMsg']
_CLEANEXECUTIONMSG = DESCRIPTOR.message_types_by_name['CleanExecutionMsg']
_STOPALLEXECUTIONSOFEMULATIONMSG = DESCRIPTOR.message_types_by_name['StopAllExecutionsOfEmulationMsg']
_CLEANALLEXECUTIONSOFEMULATIONMSG = DESCRIPTOR.message_types_by_name['CleanAllExecutionsOfEmulationMsg']
_GETCSLELOGFILESMSG = DESCRIPTOR.message_types_by_name['GetCsleLogFilesMsg']
_GETLOGFILEMSG = DESCRIPTOR.message_types_by_name['GetLogFileMsg']
_STARTCONTAINERSINEXECUTIONMSG = DESCRIPTOR.message_types_by_name['StartContainersInExecutionMsg']
_ATTACHCONTAINERSTONETWORKSINEXECUTIONMSG = DESCRIPTOR.message_types_by_name['AttachContainersToNetworksInExecutionMsg']
_INSTALLLIBRARIESMSG = DESCRIPTOR.message_types_by_name['InstallLibrariesMsg']
_APPLYKAFKACONFIGMSG = DESCRIPTOR.message_types_by_name['ApplyKafkaConfigMsg']
_STARTSDNCONTROLLERMSG = DESCRIPTOR.message_types_by_name['StartSdnControllerMsg']
_APPLYRESOUCECONSTRAINTSMSG = DESCRIPTOR.message_types_by_name['ApplyResouceConstraintsMsg']
_CREATEOVSSWITCHESMSG = DESCRIPTOR.message_types_by_name['CreateOvsSwitchesMsg']
_PINGEXECUTIONMSG = DESCRIPTOR.message_types_by_name['PingExecutionMsg']
_CONFIGUREOVSMSG = DESCRIPTOR.message_types_by_name['ConfigureOvsMsg']
_STARTSDNCONTROLLERMONITORMSG = DESCRIPTOR.message_types_by_name['StartSdnControllerMonitorMsg']
_CREATEUSERSMSG = DESCRIPTOR.message_types_by_name['CreateUsersMsg']
_CREATEVULNSMSG = DESCRIPTOR.message_types_by_name['CreateVulnsMsg']
_CREATEFLAGSMSG = DESCRIPTOR.message_types_by_name['CreateFlagsMsg']
_CREATETOPOLOGYMSG = DESCRIPTOR.message_types_by_name['CreateTopologyMsg']
_STARTTRAFFICMANAGERSMSG = DESCRIPTOR.message_types_by_name['StartTrafficManagersMsg']
_STARTTRAFFICGENERATORSMSG = DESCRIPTOR.message_types_by_name['StartTrafficGeneratorsMsg']
_STARTCLIENTPOPULATIONMSG = DESCRIPTOR.message_types_by_name['StartClientPopulationMsg']
_STARTKAFKACLIENTPRODUCERMSG = DESCRIPTOR.message_types_by_name['StartKafkaClientProducerMsg']
_STOPKAFKACLIENTPRODUCERMSG = DESCRIPTOR.message_types_by_name['StopKafkaClientProducerMsg']
_STARTSNORTIDSESMSG = DESCRIPTOR.message_types_by_name['StartSnortIdsesMsg']
_STARTSNORTIDSESMONITORTHREADSMSG = DESCRIPTOR.message_types_by_name['StartSnortIdsesMonitorThreadsMsg']
_STARTOSSECIDSESMSG = DESCRIPTOR.message_types_by_name['StartOSSECIdsesMsg']
_STARTOSSECIDSESMONITORTHREADSMSG = DESCRIPTOR.message_types_by_name['StartOSSECIdsesMonitorThreadsMsg']
_STARTELKSTACKMSG = DESCRIPTOR.message_types_by_name['StartElkStackMsg']
_STARTHOSTMANAGERSMSG = DESCRIPTOR.message_types_by_name['StartHostManagersMsg']
_APPLYFILEBEATCONFIGSMSG = DESCRIPTOR.message_types_by_name['ApplyFileBeatConfigsMsg']
_APPLYPACKETBEATCONFIGSMSG = DESCRIPTOR.message_types_by_name['ApplyPacketBeatConfigsMsg']
_APPLYMETRICBEATCONFIGSMSG = DESCRIPTOR.message_types_by_name['ApplyMetricBeatConfigsMsg']
_APPLYHEARTBEATCONFIGSMSG = DESCRIPTOR.message_types_by_name['ApplyHeartBeatConfigsMsg']
_STARTFILEBEATSMSG = DESCRIPTOR.message_types_by_name['StartFileBeatsMsg']
_STARTPACKETBEATSMSG = DESCRIPTOR.message_types_by_name['StartPacketBeatsMsg']
_STARTMETRICBEATSMSG = DESCRIPTOR.message_types_by_name['StartMetricBeatsMsg']
_STARTHEARTBEATSMSG = DESCRIPTOR.message_types_by_name['StartHeartBeatsMsg']
_GETDOCKERSTATSMANAGERLOGSMSG = DESCRIPTOR.message_types_by_name['GetDockerStatsManagerLogsMsg']
_GETPROMETHEUSLOGSMSG = DESCRIPTOR.message_types_by_name['GetPrometheusLogsMsg']
_GETNODEEXPORTERLOGSMSG = DESCRIPTOR.message_types_by_name['GetNodeExporterLogsMsg']
_GETCADVISORLOGSMSG = DESCRIPTOR.message_types_by_name['GetCAdvisorLogsMsg']
_GETPGADMINLOGSMSG = DESCRIPTOR.message_types_by_name['GetPgAdminLogsMsg']
_GETGRAFANALOGSMSG = DESCRIPTOR.message_types_by_name['GetGrafanaLogsMsg']
_GETNGINXLOGSMSG = DESCRIPTOR.message_types_by_name['GetNginxLogsMsg']
_GETDOCKERLOGSMSG = DESCRIPTOR.message_types_by_name['GetDockerLogsMsg']
_GETPOSTGRESQLLOGSMSG = DESCRIPTOR.message_types_by_name['GetPostgreSQLLogsMsg']
_GETFLASKLOGSMSG = DESCRIPTOR.message_types_by_name['GetFlaskLogsMsg']
_LOGSDTO = DESCRIPTOR.message_types_by_name['LogsDTO']
_OPERATIONOUTCOMEDTO = DESCRIPTOR.message_types_by_name['OperationOutcomeDTO']
_GETNODESTATUSMSG = DESCRIPTOR.message_types_by_name['GetNodeStatusMsg']
_NODESTATUSDTO = DESCRIPTOR.message_types_by_name['NodeStatusDTO']
_SERVICESTATUSDTO = DESCRIPTOR.message_types_by_name['ServiceStatusDTO']
_STARTPOSTGRESQLMSG = DESCRIPTOR.message_types_by_name['StartPostgreSQLMsg']
_STARTCADVISORMSG = DESCRIPTOR.message_types_by_name['StartCAdvisorMsg']
_STARTNODEEXPORTERMSG = DESCRIPTOR.message_types_by_name['StartNodeExporterMsg']
_STARTGRAFANAMSG = DESCRIPTOR.message_types_by_name['StartGrafanaMsg']
_STARTPROMETHEUSMSG = DESCRIPTOR.message_types_by_name['StartPrometheusMsg']
_STARTPGADMINMSG = DESCRIPTOR.message_types_by_name['StartPgAdminMsg']
_STARTNGINXMSG = DESCRIPTOR.message_types_by_name['StartNginxMsg']
_STARTFLASKMSG = DESCRIPTOR.message_types_by_name['StartFlaskMsg']
_STARTDOCKERSTATSMANAGERMSG = DESCRIPTOR.message_types_by_name['StartDockerStatsManagerMsg']
_STARTDOCKERSTATSMANAGERTHREADMSG = DESCRIPTOR.message_types_by_name['StartDockerStatsManagerThreadMsg']
_STARTDOCKERENGINEMSG = DESCRIPTOR.message_types_by_name['StartDockerEngineMsg']
_STOPPOSTGRESQLMSG = DESCRIPTOR.message_types_by_name['StopPostgreSQLMsg']
_STOPCADVISORMSG = DESCRIPTOR.message_types_by_name['StopCAdvisorMsg']
_STOPNODEEXPORTERMSG = DESCRIPTOR.message_types_by_name['StopNodeExporterMsg']
_STOPGRAFANAMSG = DESCRIPTOR.message_types_by_name['StopGrafanaMsg']
_STOPPROMETHEUSMSG = DESCRIPTOR.message_types_by_name['StopPrometheusMsg']
_STOPPGADMINMSG = DESCRIPTOR.message_types_by_name['StopPgAdminMsg']
_STOPNGINXMSG = DESCRIPTOR.message_types_by_name['StopNginxMsg']
_STOPFLASKMSG = DESCRIPTOR.message_types_by_name['StopFlaskMsg']
_STOPDOCKERSTATSMANAGERMSG = DESCRIPTOR.message_types_by_name['StopDockerStatsManagerMsg']
_STOPDOCKERENGINEMSG = DESCRIPTOR.message_types_by_name['StopDockerEngineMsg']
StopPidMsg = _reflection.GeneratedProtocolMessageType('StopPidMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPPIDMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopPidMsg)
  })
_sym_db.RegisterMessage(StopPidMsg)

CheckPidMsg = _reflection.GeneratedProtocolMessageType('CheckPidMsg', (_message.Message,), {
  'DESCRIPTOR' : _CHECKPIDMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:CheckPidMsg)
  })
_sym_db.RegisterMessage(CheckPidMsg)

StartSparkServerMsg = _reflection.GeneratedProtocolMessageType('StartSparkServerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTSPARKSERVERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartSparkServerMsg)
  })
_sym_db.RegisterMessage(StartSparkServerMsg)

StopSparkServerMsg = _reflection.GeneratedProtocolMessageType('StopSparkServerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPSPARKSERVERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopSparkServerMsg)
  })
_sym_db.RegisterMessage(StopSparkServerMsg)

StartSparkServersMsg = _reflection.GeneratedProtocolMessageType('StartSparkServersMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTSPARKSERVERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartSparkServersMsg)
  })
_sym_db.RegisterMessage(StartSparkServersMsg)

StopSparkServersMsg = _reflection.GeneratedProtocolMessageType('StopSparkServersMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPSPARKSERVERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopSparkServersMsg)
  })
_sym_db.RegisterMessage(StopSparkServersMsg)

GetExecutionTimeSeriesDataMsg = _reflection.GeneratedProtocolMessageType('GetExecutionTimeSeriesDataMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETEXECUTIONTIMESERIESDATAMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetExecutionTimeSeriesDataMsg)
  })
_sym_db.RegisterMessage(GetExecutionTimeSeriesDataMsg)

EmulationMetricsTimeSeriesDTO = _reflection.GeneratedProtocolMessageType('EmulationMetricsTimeSeriesDTO', (_message.Message,), {
  'DESCRIPTOR' : _EMULATIONMETRICSTIMESERIESDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:EmulationMetricsTimeSeriesDTO)
  })
_sym_db.RegisterMessage(EmulationMetricsTimeSeriesDTO)

AvgPortStatisticDict = _reflection.GeneratedProtocolMessageType('AvgPortStatisticDict', (_message.Message,), {
  'DESCRIPTOR' : _AVGPORTSTATISTICDICT,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:AvgPortStatisticDict)
  })
_sym_db.RegisterMessage(AvgPortStatisticDict)

AggFlowStatisticDict = _reflection.GeneratedProtocolMessageType('AggFlowStatisticDict', (_message.Message,), {
  'DESCRIPTOR' : _AGGFLOWSTATISTICDICT,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:AggFlowStatisticDict)
  })
_sym_db.RegisterMessage(AggFlowStatisticDict)

AvgFlowStatisticDict = _reflection.GeneratedProtocolMessageType('AvgFlowStatisticDict', (_message.Message,), {
  'DESCRIPTOR' : _AVGFLOWSTATISTICDICT,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:AvgFlowStatisticDict)
  })
_sym_db.RegisterMessage(AvgFlowStatisticDict)

PortStatisticDict = _reflection.GeneratedProtocolMessageType('PortStatisticDict', (_message.Message,), {
  'DESCRIPTOR' : _PORTSTATISTICDICT,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:PortStatisticDict)
  })
_sym_db.RegisterMessage(PortStatisticDict)

FlowStatisticDict = _reflection.GeneratedProtocolMessageType('FlowStatisticDict', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSTATISTICDICT,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:FlowStatisticDict)
  })
_sym_db.RegisterMessage(FlowStatisticDict)

OSSECIdsAlertCountersDict = _reflection.GeneratedProtocolMessageType('OSSECIdsAlertCountersDict', (_message.Message,), {
  'DESCRIPTOR' : _OSSECIDSALERTCOUNTERSDICT,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:OSSECIdsAlertCountersDict)
  })
_sym_db.RegisterMessage(OSSECIdsAlertCountersDict)

HostMetricsDict = _reflection.GeneratedProtocolMessageType('HostMetricsDict', (_message.Message,), {
  'DESCRIPTOR' : _HOSTMETRICSDICT,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:HostMetricsDict)
  })
_sym_db.RegisterMessage(HostMetricsDict)

DockerStatsDict = _reflection.GeneratedProtocolMessageType('DockerStatsDict', (_message.Message,), {
  'DESCRIPTOR' : _DOCKERSTATSDICT,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:DockerStatsDict)
  })
_sym_db.RegisterMessage(DockerStatsDict)

AvgPortStatisticDTO = _reflection.GeneratedProtocolMessageType('AvgPortStatisticDTO', (_message.Message,), {
  'DESCRIPTOR' : _AVGPORTSTATISTICDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:AvgPortStatisticDTO)
  })
_sym_db.RegisterMessage(AvgPortStatisticDTO)

AvgFlowStatisticDTO = _reflection.GeneratedProtocolMessageType('AvgFlowStatisticDTO', (_message.Message,), {
  'DESCRIPTOR' : _AVGFLOWSTATISTICDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:AvgFlowStatisticDTO)
  })
_sym_db.RegisterMessage(AvgFlowStatisticDTO)

AggFlowStatisticDTO = _reflection.GeneratedProtocolMessageType('AggFlowStatisticDTO', (_message.Message,), {
  'DESCRIPTOR' : _AGGFLOWSTATISTICDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:AggFlowStatisticDTO)
  })
_sym_db.RegisterMessage(AggFlowStatisticDTO)

PortStatisticDTO = _reflection.GeneratedProtocolMessageType('PortStatisticDTO', (_message.Message,), {
  'DESCRIPTOR' : _PORTSTATISTICDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:PortStatisticDTO)
  })
_sym_db.RegisterMessage(PortStatisticDTO)

FlowStatisticDTO = _reflection.GeneratedProtocolMessageType('FlowStatisticDTO', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSTATISTICDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:FlowStatisticDTO)
  })
_sym_db.RegisterMessage(FlowStatisticDTO)

OSSECIdsAlertCountersDTO = _reflection.GeneratedProtocolMessageType('OSSECIdsAlertCountersDTO', (_message.Message,), {
  'DESCRIPTOR' : _OSSECIDSALERTCOUNTERSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:OSSECIdsAlertCountersDTO)
  })
_sym_db.RegisterMessage(OSSECIdsAlertCountersDTO)

SnortIdsAlertCountersDTO = _reflection.GeneratedProtocolMessageType('SnortIdsAlertCountersDTO', (_message.Message,), {
  'DESCRIPTOR' : _SNORTIDSALERTCOUNTERSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:SnortIdsAlertCountersDTO)
  })
_sym_db.RegisterMessage(SnortIdsAlertCountersDTO)

SnortIdsIpAlertCountersDict = _reflection.GeneratedProtocolMessageType('SnortIdsIpAlertCountersDict', (_message.Message,), {
  'DESCRIPTOR' : _SNORTIDSIPALERTCOUNTERSDICT,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:SnortIdsIpAlertCountersDict)
  })
_sym_db.RegisterMessage(SnortIdsIpAlertCountersDict)

SnortIdsAlertCountersDict = _reflection.GeneratedProtocolMessageType('SnortIdsAlertCountersDict', (_message.Message,), {
  'DESCRIPTOR' : _SNORTIDSALERTCOUNTERSDICT,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:SnortIdsAlertCountersDict)
  })
_sym_db.RegisterMessage(SnortIdsAlertCountersDict)

SnortIdsRuleCountersDict = _reflection.GeneratedProtocolMessageType('SnortIdsRuleCountersDict', (_message.Message,), {
  'DESCRIPTOR' : _SNORTIDSRULECOUNTERSDICT,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:SnortIdsRuleCountersDict)
  })
_sym_db.RegisterMessage(SnortIdsRuleCountersDict)

SnortIdsIpAlertCountersDTO = _reflection.GeneratedProtocolMessageType('SnortIdsIpAlertCountersDTO', (_message.Message,), {
  'DESCRIPTOR' : _SNORTIDSIPALERTCOUNTERSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:SnortIdsIpAlertCountersDTO)
  })
_sym_db.RegisterMessage(SnortIdsIpAlertCountersDTO)

SnortIdsRuleCountersDTO = _reflection.GeneratedProtocolMessageType('SnortIdsRuleCountersDTO', (_message.Message,), {
  'DESCRIPTOR' : _SNORTIDSRULECOUNTERSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:SnortIdsRuleCountersDTO)
  })
_sym_db.RegisterMessage(SnortIdsRuleCountersDTO)

EmulationAttackerActionDTO = _reflection.GeneratedProtocolMessageType('EmulationAttackerActionDTO', (_message.Message,), {
  'DESCRIPTOR' : _EMULATIONATTACKERACTIONDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:EmulationAttackerActionDTO)
  })
_sym_db.RegisterMessage(EmulationAttackerActionDTO)

EmulationDefenderActionDTO = _reflection.GeneratedProtocolMessageType('EmulationDefenderActionDTO', (_message.Message,), {
  'DESCRIPTOR' : _EMULATIONDEFENDERACTIONDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:EmulationDefenderActionDTO)
  })
_sym_db.RegisterMessage(EmulationDefenderActionDTO)

HostMetricsDataDTO = _reflection.GeneratedProtocolMessageType('HostMetricsDataDTO', (_message.Message,), {
  'DESCRIPTOR' : _HOSTMETRICSDATADTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:HostMetricsDataDTO)
  })
_sym_db.RegisterMessage(HostMetricsDataDTO)

DockerStatsDTO = _reflection.GeneratedProtocolMessageType('DockerStatsDTO', (_message.Message,), {
  'DESCRIPTOR' : _DOCKERSTATSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:DockerStatsDTO)
  })
_sym_db.RegisterMessage(DockerStatsDTO)

ClientPopulationMetricsDTO = _reflection.GeneratedProtocolMessageType('ClientPopulationMetricsDTO', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTPOPULATIONMETRICSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ClientPopulationMetricsDTO)
  })
_sym_db.RegisterMessage(ClientPopulationMetricsDTO)

GetClusterManagerLogsMsg = _reflection.GeneratedProtocolMessageType('GetClusterManagerLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERMANAGERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetClusterManagerLogsMsg)
  })
_sym_db.RegisterMessage(GetClusterManagerLogsMsg)

GetContainerLogsMsg = _reflection.GeneratedProtocolMessageType('GetContainerLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTAINERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetContainerLogsMsg)
  })
_sym_db.RegisterMessage(GetContainerLogsMsg)

GetClientManagerLogsMsg = _reflection.GeneratedProtocolMessageType('GetClientManagerLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETCLIENTMANAGERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetClientManagerLogsMsg)
  })
_sym_db.RegisterMessage(GetClientManagerLogsMsg)

GetKafkaManagerLogsMsg = _reflection.GeneratedProtocolMessageType('GetKafkaManagerLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKAMANAGERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetKafkaManagerLogsMsg)
  })
_sym_db.RegisterMessage(GetKafkaManagerLogsMsg)

GetKafkaLogsMsg = _reflection.GeneratedProtocolMessageType('GetKafkaLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKALOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetKafkaLogsMsg)
  })
_sym_db.RegisterMessage(GetKafkaLogsMsg)

GetSnortIdsLogsMsg = _reflection.GeneratedProtocolMessageType('GetSnortIdsLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETSNORTIDSLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetSnortIdsLogsMsg)
  })
_sym_db.RegisterMessage(GetSnortIdsLogsMsg)

GetSnortIdsManagerLogsMsg = _reflection.GeneratedProtocolMessageType('GetSnortIdsManagerLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETSNORTIDSMANAGERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetSnortIdsManagerLogsMsg)
  })
_sym_db.RegisterMessage(GetSnortIdsManagerLogsMsg)

GetOSSECIdsManagerLogsMsg = _reflection.GeneratedProtocolMessageType('GetOSSECIdsManagerLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETOSSECIDSMANAGERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetOSSECIdsManagerLogsMsg)
  })
_sym_db.RegisterMessage(GetOSSECIdsManagerLogsMsg)

GetOSSECIdsLogsMsg = _reflection.GeneratedProtocolMessageType('GetOSSECIdsLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETOSSECIDSLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetOSSECIdsLogsMsg)
  })
_sym_db.RegisterMessage(GetOSSECIdsLogsMsg)

GetHostManagerLogsMsg = _reflection.GeneratedProtocolMessageType('GetHostManagerLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTMANAGERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetHostManagerLogsMsg)
  })
_sym_db.RegisterMessage(GetHostManagerLogsMsg)

GetTrafficManagerLogsMsg = _reflection.GeneratedProtocolMessageType('GetTrafficManagerLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETTRAFFICMANAGERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetTrafficManagerLogsMsg)
  })
_sym_db.RegisterMessage(GetTrafficManagerLogsMsg)

GetElkManagerLogsMsg = _reflection.GeneratedProtocolMessageType('GetElkManagerLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETELKMANAGERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetElkManagerLogsMsg)
  })
_sym_db.RegisterMessage(GetElkManagerLogsMsg)

GetElkLogsMsg = _reflection.GeneratedProtocolMessageType('GetElkLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETELKLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetElkLogsMsg)
  })
_sym_db.RegisterMessage(GetElkLogsMsg)

GetRyuManagerLogsMsg = _reflection.GeneratedProtocolMessageType('GetRyuManagerLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETRYUMANAGERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetRyuManagerLogsMsg)
  })
_sym_db.RegisterMessage(GetRyuManagerLogsMsg)

GetRyuControllerLogsMsg = _reflection.GeneratedProtocolMessageType('GetRyuControllerLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETRYUCONTROLLERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetRyuControllerLogsMsg)
  })
_sym_db.RegisterMessage(GetRyuControllerLogsMsg)

StopRyuMonitorThreadMsg = _reflection.GeneratedProtocolMessageType('StopRyuMonitorThreadMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPRYUMONITORTHREADMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopRyuMonitorThreadMsg)
  })
_sym_db.RegisterMessage(StopRyuMonitorThreadMsg)

StartRyuMonitorThreadMsg = _reflection.GeneratedProtocolMessageType('StartRyuMonitorThreadMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTRYUMONITORTHREADMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartRyuMonitorThreadMsg)
  })
_sym_db.RegisterMessage(StartRyuMonitorThreadMsg)

StopHostMonitorThreadsMsg = _reflection.GeneratedProtocolMessageType('StopHostMonitorThreadsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPHOSTMONITORTHREADSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopHostMonitorThreadsMsg)
  })
_sym_db.RegisterMessage(StopHostMonitorThreadsMsg)

StopHostMonitorThreadMsg = _reflection.GeneratedProtocolMessageType('StopHostMonitorThreadMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPHOSTMONITORTHREADMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopHostMonitorThreadMsg)
  })
_sym_db.RegisterMessage(StopHostMonitorThreadMsg)

RemoveKibanaTunnelMsg = _reflection.GeneratedProtocolMessageType('RemoveKibanaTunnelMsg', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEKIBANATUNNELMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RemoveKibanaTunnelMsg)
  })
_sym_db.RegisterMessage(RemoveKibanaTunnelMsg)

CreateKibanaTunnelMsg = _reflection.GeneratedProtocolMessageType('CreateKibanaTunnelMsg', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKIBANATUNNELMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:CreateKibanaTunnelMsg)
  })
_sym_db.RegisterMessage(CreateKibanaTunnelMsg)

ListKibanaTunnelsMsg = _reflection.GeneratedProtocolMessageType('ListKibanaTunnelsMsg', (_message.Message,), {
  'DESCRIPTOR' : _LISTKIBANATUNNELSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ListKibanaTunnelsMsg)
  })
_sym_db.RegisterMessage(ListKibanaTunnelsMsg)

KibanaTunnelsDTO = _reflection.GeneratedProtocolMessageType('KibanaTunnelsDTO', (_message.Message,), {
  'DESCRIPTOR' : _KIBANATUNNELSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:KibanaTunnelsDTO)
  })
_sym_db.RegisterMessage(KibanaTunnelsDTO)

KibanaTunnelDTO = _reflection.GeneratedProtocolMessageType('KibanaTunnelDTO', (_message.Message,), {
  'DESCRIPTOR' : _KIBANATUNNELDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:KibanaTunnelDTO)
  })
_sym_db.RegisterMessage(KibanaTunnelDTO)

RemoveRyuTunnelMsg = _reflection.GeneratedProtocolMessageType('RemoveRyuTunnelMsg', (_message.Message,), {
  'DESCRIPTOR' : _REMOVERYUTUNNELMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RemoveRyuTunnelMsg)
  })
_sym_db.RegisterMessage(RemoveRyuTunnelMsg)

CreateRyuTunnelMsg = _reflection.GeneratedProtocolMessageType('CreateRyuTunnelMsg', (_message.Message,), {
  'DESCRIPTOR' : _CREATERYUTUNNELMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:CreateRyuTunnelMsg)
  })
_sym_db.RegisterMessage(CreateRyuTunnelMsg)

ListRyuTunnelsMsg = _reflection.GeneratedProtocolMessageType('ListRyuTunnelsMsg', (_message.Message,), {
  'DESCRIPTOR' : _LISTRYUTUNNELSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ListRyuTunnelsMsg)
  })
_sym_db.RegisterMessage(ListRyuTunnelsMsg)

RyuTunnelsDTO = _reflection.GeneratedProtocolMessageType('RyuTunnelsDTO', (_message.Message,), {
  'DESCRIPTOR' : _RYUTUNNELSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RyuTunnelsDTO)
  })
_sym_db.RegisterMessage(RyuTunnelsDTO)

RyuTunnelDTO = _reflection.GeneratedProtocolMessageType('RyuTunnelDTO', (_message.Message,), {
  'DESCRIPTOR' : _RYUTUNNELDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RyuTunnelDTO)
  })
_sym_db.RegisterMessage(RyuTunnelDTO)

SnortIdsMonitorThreadStatusesDTO = _reflection.GeneratedProtocolMessageType('SnortIdsMonitorThreadStatusesDTO', (_message.Message,), {
  'DESCRIPTOR' : _SNORTIDSMONITORTHREADSTATUSESDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:SnortIdsMonitorThreadStatusesDTO)
  })
_sym_db.RegisterMessage(SnortIdsMonitorThreadStatusesDTO)

GetSnortIdsManagersInfoMsg = _reflection.GeneratedProtocolMessageType('GetSnortIdsManagersInfoMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETSNORTIDSMANAGERSINFOMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetSnortIdsManagersInfoMsg)
  })
_sym_db.RegisterMessage(GetSnortIdsManagersInfoMsg)

GetSnortIdsMonitorThreadStatusesMsg = _reflection.GeneratedProtocolMessageType('GetSnortIdsMonitorThreadStatusesMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETSNORTIDSMONITORTHREADSTATUSESMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetSnortIdsMonitorThreadStatusesMsg)
  })
_sym_db.RegisterMessage(GetSnortIdsMonitorThreadStatusesMsg)

StopSnortIdsMonitorThreadsMsg = _reflection.GeneratedProtocolMessageType('StopSnortIdsMonitorThreadsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPSNORTIDSMONITORTHREADSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopSnortIdsMonitorThreadsMsg)
  })
_sym_db.RegisterMessage(StopSnortIdsMonitorThreadsMsg)

StopSnortIdsManagerMsg = _reflection.GeneratedProtocolMessageType('StopSnortIdsManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPSNORTIDSMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopSnortIdsManagerMsg)
  })
_sym_db.RegisterMessage(StopSnortIdsManagerMsg)

StartSnortIdsManagerMsg = _reflection.GeneratedProtocolMessageType('StartSnortIdsManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTSNORTIDSMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartSnortIdsManagerMsg)
  })
_sym_db.RegisterMessage(StartSnortIdsManagerMsg)

StopSnortIdsManagersMsg = _reflection.GeneratedProtocolMessageType('StopSnortIdsManagersMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPSNORTIDSMANAGERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopSnortIdsManagersMsg)
  })
_sym_db.RegisterMessage(StopSnortIdsManagersMsg)

StartSnortIdsManagersMsg = _reflection.GeneratedProtocolMessageType('StartSnortIdsManagersMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTSNORTIDSMANAGERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartSnortIdsManagersMsg)
  })
_sym_db.RegisterMessage(StartSnortIdsManagersMsg)

StartSnortMsg = _reflection.GeneratedProtocolMessageType('StartSnortMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTSNORTMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartSnortMsg)
  })
_sym_db.RegisterMessage(StartSnortMsg)

StartSnortIdsMonitorThreadMsg = _reflection.GeneratedProtocolMessageType('StartSnortIdsMonitorThreadMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTSNORTIDSMONITORTHREADMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartSnortIdsMonitorThreadMsg)
  })
_sym_db.RegisterMessage(StartSnortIdsMonitorThreadMsg)

StartSnortIdsMonitorThreadsMsg = _reflection.GeneratedProtocolMessageType('StartSnortIdsMonitorThreadsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTSNORTIDSMONITORTHREADSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartSnortIdsMonitorThreadsMsg)
  })
_sym_db.RegisterMessage(StartSnortIdsMonitorThreadsMsg)

StopSnortMsg = _reflection.GeneratedProtocolMessageType('StopSnortMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPSNORTMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopSnortMsg)
  })
_sym_db.RegisterMessage(StopSnortMsg)

StopSnortIdsMonitorThreadMsg = _reflection.GeneratedProtocolMessageType('StopSnortIdsMonitorThreadMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPSNORTIDSMONITORTHREADMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopSnortIdsMonitorThreadMsg)
  })
_sym_db.RegisterMessage(StopSnortIdsMonitorThreadMsg)

StopSnortIdsesMsg = _reflection.GeneratedProtocolMessageType('StopSnortIdsesMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPSNORTIDSESMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopSnortIdsesMsg)
  })
_sym_db.RegisterMessage(StopSnortIdsesMsg)

StopSnortIdsesMonitorThreadsMsg = _reflection.GeneratedProtocolMessageType('StopSnortIdsesMonitorThreadsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPSNORTIDSESMONITORTHREADSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopSnortIdsesMonitorThreadsMsg)
  })
_sym_db.RegisterMessage(StopSnortIdsesMonitorThreadsMsg)

GetRyuManagersInfoMsg = _reflection.GeneratedProtocolMessageType('GetRyuManagersInfoMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETRYUMANAGERSINFOMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetRyuManagersInfoMsg)
  })
_sym_db.RegisterMessage(GetRyuManagersInfoMsg)

StopRyuMonitorServiceMsg = _reflection.GeneratedProtocolMessageType('StopRyuMonitorServiceMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPRYUMONITORSERVICEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopRyuMonitorServiceMsg)
  })
_sym_db.RegisterMessage(StopRyuMonitorServiceMsg)

StartRyuMonitorServiceMsg = _reflection.GeneratedProtocolMessageType('StartRyuMonitorServiceMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTRYUMONITORSERVICEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartRyuMonitorServiceMsg)
  })
_sym_db.RegisterMessage(StartRyuMonitorServiceMsg)

StopRyuServiceMsg = _reflection.GeneratedProtocolMessageType('StopRyuServiceMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPRYUSERVICEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopRyuServiceMsg)
  })
_sym_db.RegisterMessage(StopRyuServiceMsg)

StartRyuServiceMsg = _reflection.GeneratedProtocolMessageType('StartRyuServiceMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTRYUSERVICEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartRyuServiceMsg)
  })
_sym_db.RegisterMessage(StartRyuServiceMsg)

GetRyuServiceStatusMsg = _reflection.GeneratedProtocolMessageType('GetRyuServiceStatusMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETRYUSERVICESTATUSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetRyuServiceStatusMsg)
  })
_sym_db.RegisterMessage(GetRyuServiceStatusMsg)

StopRyuManagerMsg = _reflection.GeneratedProtocolMessageType('StopRyuManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPRYUMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopRyuManagerMsg)
  })
_sym_db.RegisterMessage(StopRyuManagerMsg)

StartRyuManagerMsg = _reflection.GeneratedProtocolMessageType('StartRyuManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTRYUMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartRyuManagerMsg)
  })
_sym_db.RegisterMessage(StartRyuManagerMsg)

GetOSSECIDSManagersInfoMsg = _reflection.GeneratedProtocolMessageType('GetOSSECIDSManagersInfoMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETOSSECIDSMANAGERSINFOMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetOSSECIDSManagersInfoMsg)
  })
_sym_db.RegisterMessage(GetOSSECIDSManagersInfoMsg)

OSSECIdsMonitorThreadStatusesDTO = _reflection.GeneratedProtocolMessageType('OSSECIdsMonitorThreadStatusesDTO', (_message.Message,), {
  'DESCRIPTOR' : _OSSECIDSMONITORTHREADSTATUSESDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:OSSECIdsMonitorThreadStatusesDTO)
  })
_sym_db.RegisterMessage(OSSECIdsMonitorThreadStatusesDTO)

GetOSSECIDSMonitorThreadStatusesMsg = _reflection.GeneratedProtocolMessageType('GetOSSECIDSMonitorThreadStatusesMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETOSSECIDSMONITORTHREADSTATUSESMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetOSSECIDSMonitorThreadStatusesMsg)
  })
_sym_db.RegisterMessage(GetOSSECIDSMonitorThreadStatusesMsg)

StopOSSECIDSMonitorThreadsMsg = _reflection.GeneratedProtocolMessageType('StopOSSECIDSMonitorThreadsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPOSSECIDSMONITORTHREADSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopOSSECIDSMonitorThreadsMsg)
  })
_sym_db.RegisterMessage(StopOSSECIDSMonitorThreadsMsg)

StopOSSECIDSMonitorThreadMsg = _reflection.GeneratedProtocolMessageType('StopOSSECIDSMonitorThreadMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPOSSECIDSMONITORTHREADMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopOSSECIDSMonitorThreadMsg)
  })
_sym_db.RegisterMessage(StopOSSECIDSMonitorThreadMsg)

StartOSSECIDSMonitorThreadMsg = _reflection.GeneratedProtocolMessageType('StartOSSECIDSMonitorThreadMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTOSSECIDSMONITORTHREADMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartOSSECIDSMonitorThreadMsg)
  })
_sym_db.RegisterMessage(StartOSSECIDSMonitorThreadMsg)

StopOSSECIDSManager = _reflection.GeneratedProtocolMessageType('StopOSSECIDSManager', (_message.Message,), {
  'DESCRIPTOR' : _STOPOSSECIDSMANAGER,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopOSSECIDSManager)
  })
_sym_db.RegisterMessage(StopOSSECIDSManager)

StartOSSECIDSManager = _reflection.GeneratedProtocolMessageType('StartOSSECIDSManager', (_message.Message,), {
  'DESCRIPTOR' : _STARTOSSECIDSMANAGER,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartOSSECIDSManager)
  })
_sym_db.RegisterMessage(StartOSSECIDSManager)

StopOSSECIDSManagers = _reflection.GeneratedProtocolMessageType('StopOSSECIDSManagers', (_message.Message,), {
  'DESCRIPTOR' : _STOPOSSECIDSMANAGERS,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopOSSECIDSManagers)
  })
_sym_db.RegisterMessage(StopOSSECIDSManagers)

StartOSSECIDSManagers = _reflection.GeneratedProtocolMessageType('StartOSSECIDSManagers', (_message.Message,), {
  'DESCRIPTOR' : _STARTOSSECIDSMANAGERS,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartOSSECIDSManagers)
  })
_sym_db.RegisterMessage(StartOSSECIDSManagers)

StartOSSECIDSMsg = _reflection.GeneratedProtocolMessageType('StartOSSECIDSMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTOSSECIDSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartOSSECIDSMsg)
  })
_sym_db.RegisterMessage(StartOSSECIDSMsg)

StopOSSECIDSMsg = _reflection.GeneratedProtocolMessageType('StopOSSECIDSMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPOSSECIDSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopOSSECIDSMsg)
  })
_sym_db.RegisterMessage(StopOSSECIDSMsg)

StartOSSECIDSesMsg = _reflection.GeneratedProtocolMessageType('StartOSSECIDSesMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTOSSECIDSESMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartOSSECIDSesMsg)
  })
_sym_db.RegisterMessage(StartOSSECIDSesMsg)

StopOSSECIDSesMsg = _reflection.GeneratedProtocolMessageType('StopOSSECIDSesMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPOSSECIDSESMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopOSSECIDSesMsg)
  })
_sym_db.RegisterMessage(StopOSSECIDSesMsg)

GetKafkaManagersInfoMsg = _reflection.GeneratedProtocolMessageType('GetKafkaManagersInfoMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKAMANAGERSINFOMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetKafkaManagersInfoMsg)
  })
_sym_db.RegisterMessage(GetKafkaManagersInfoMsg)

StartKafkaServerMsg = _reflection.GeneratedProtocolMessageType('StartKafkaServerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTKAFKASERVERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartKafkaServerMsg)
  })
_sym_db.RegisterMessage(StartKafkaServerMsg)

StopKafkaServerMsg = _reflection.GeneratedProtocolMessageType('StopKafkaServerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPKAFKASERVERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopKafkaServerMsg)
  })
_sym_db.RegisterMessage(StopKafkaServerMsg)

GetKafkaManagerStatusMsg = _reflection.GeneratedProtocolMessageType('GetKafkaManagerStatusMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKAMANAGERSTATUSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetKafkaManagerStatusMsg)
  })
_sym_db.RegisterMessage(GetKafkaManagerStatusMsg)

CreateKafkaTopicsMsg = _reflection.GeneratedProtocolMessageType('CreateKafkaTopicsMsg', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKAFKATOPICSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:CreateKafkaTopicsMsg)
  })
_sym_db.RegisterMessage(CreateKafkaTopicsMsg)

StopKafkaManagerMsg = _reflection.GeneratedProtocolMessageType('StopKafkaManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPKAFKAMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopKafkaManagerMsg)
  })
_sym_db.RegisterMessage(StopKafkaManagerMsg)

StartKafkaManagerMsg = _reflection.GeneratedProtocolMessageType('StartKafkaManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTKAFKAMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartKafkaManagerMsg)
  })
_sym_db.RegisterMessage(StartKafkaManagerMsg)

GetHostManagersInfoMsg = _reflection.GeneratedProtocolMessageType('GetHostManagersInfoMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTMANAGERSINFOMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetHostManagersInfoMsg)
  })
_sym_db.RegisterMessage(GetHostManagersInfoMsg)

GetHostMonitorThreadsStatusesMsg = _reflection.GeneratedProtocolMessageType('GetHostMonitorThreadsStatusesMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTMONITORTHREADSSTATUSESMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetHostMonitorThreadsStatusesMsg)
  })
_sym_db.RegisterMessage(GetHostMonitorThreadsStatusesMsg)

ApplyFileBeatConfigMsg = _reflection.GeneratedProtocolMessageType('ApplyFileBeatConfigMsg', (_message.Message,), {
  'DESCRIPTOR' : _APPLYFILEBEATCONFIGMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ApplyFileBeatConfigMsg)
  })
_sym_db.RegisterMessage(ApplyFileBeatConfigMsg)

ApplyPacketBeatConfigMsg = _reflection.GeneratedProtocolMessageType('ApplyPacketBeatConfigMsg', (_message.Message,), {
  'DESCRIPTOR' : _APPLYPACKETBEATCONFIGMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ApplyPacketBeatConfigMsg)
  })
_sym_db.RegisterMessage(ApplyPacketBeatConfigMsg)

ApplyMetricBeatConfigMsg = _reflection.GeneratedProtocolMessageType('ApplyMetricBeatConfigMsg', (_message.Message,), {
  'DESCRIPTOR' : _APPLYMETRICBEATCONFIGMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ApplyMetricBeatConfigMsg)
  })
_sym_db.RegisterMessage(ApplyMetricBeatConfigMsg)

ApplyHeartBeatConfigMsg = _reflection.GeneratedProtocolMessageType('ApplyHeartBeatConfigMsg', (_message.Message,), {
  'DESCRIPTOR' : _APPLYHEARTBEATCONFIGMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ApplyHeartBeatConfigMsg)
  })
_sym_db.RegisterMessage(ApplyHeartBeatConfigMsg)

StopFileBeatMsg = _reflection.GeneratedProtocolMessageType('StopFileBeatMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPFILEBEATMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopFileBeatMsg)
  })
_sym_db.RegisterMessage(StopFileBeatMsg)

StopPacketBeatMsg = _reflection.GeneratedProtocolMessageType('StopPacketBeatMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPPACKETBEATMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopPacketBeatMsg)
  })
_sym_db.RegisterMessage(StopPacketBeatMsg)

StopMetricBeatMsg = _reflection.GeneratedProtocolMessageType('StopMetricBeatMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPMETRICBEATMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopMetricBeatMsg)
  })
_sym_db.RegisterMessage(StopMetricBeatMsg)

StopHeartBeatMsg = _reflection.GeneratedProtocolMessageType('StopHeartBeatMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPHEARTBEATMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopHeartBeatMsg)
  })
_sym_db.RegisterMessage(StopHeartBeatMsg)

StartFileBeatMsg = _reflection.GeneratedProtocolMessageType('StartFileBeatMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTFILEBEATMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartFileBeatMsg)
  })
_sym_db.RegisterMessage(StartFileBeatMsg)

StartPacketBeatMsg = _reflection.GeneratedProtocolMessageType('StartPacketBeatMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTPACKETBEATMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartPacketBeatMsg)
  })
_sym_db.RegisterMessage(StartPacketBeatMsg)

StartMetricBeatMsg = _reflection.GeneratedProtocolMessageType('StartMetricBeatMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTMETRICBEATMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartMetricBeatMsg)
  })
_sym_db.RegisterMessage(StartMetricBeatMsg)

StartHeartBeatMsg = _reflection.GeneratedProtocolMessageType('StartHeartBeatMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTHEARTBEATMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartHeartBeatMsg)
  })
_sym_db.RegisterMessage(StartHeartBeatMsg)

StartHostMonitorThreadMsg = _reflection.GeneratedProtocolMessageType('StartHostMonitorThreadMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTHOSTMONITORTHREADMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartHostMonitorThreadMsg)
  })
_sym_db.RegisterMessage(StartHostMonitorThreadMsg)

StopHeartbeatsMsg = _reflection.GeneratedProtocolMessageType('StopHeartbeatsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPHEARTBEATSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopHeartbeatsMsg)
  })
_sym_db.RegisterMessage(StopHeartbeatsMsg)

StopPacketbeatsMsg = _reflection.GeneratedProtocolMessageType('StopPacketbeatsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPPACKETBEATSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopPacketbeatsMsg)
  })
_sym_db.RegisterMessage(StopPacketbeatsMsg)

StopFilebeatsMsg = _reflection.GeneratedProtocolMessageType('StopFilebeatsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPFILEBEATSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopFilebeatsMsg)
  })
_sym_db.RegisterMessage(StopFilebeatsMsg)

StopMetricbeatsMsg = _reflection.GeneratedProtocolMessageType('StopMetricbeatsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPMETRICBEATSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopMetricbeatsMsg)
  })
_sym_db.RegisterMessage(StopMetricbeatsMsg)

StartHostMonitorThreadsMsg = _reflection.GeneratedProtocolMessageType('StartHostMonitorThreadsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTHOSTMONITORTHREADSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartHostMonitorThreadsMsg)
  })
_sym_db.RegisterMessage(StartHostMonitorThreadsMsg)

StopHostManagerMsg = _reflection.GeneratedProtocolMessageType('StopHostManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPHOSTMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopHostManagerMsg)
  })
_sym_db.RegisterMessage(StopHostManagerMsg)

StartHostManagerMsg = _reflection.GeneratedProtocolMessageType('StartHostManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTHOSTMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartHostManagerMsg)
  })
_sym_db.RegisterMessage(StartHostManagerMsg)

StopHostManagersMsg = _reflection.GeneratedProtocolMessageType('StopHostManagersMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPHOSTMANAGERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopHostManagersMsg)
  })
_sym_db.RegisterMessage(StopHostManagersMsg)

ExecutionInfoDTO = _reflection.GeneratedProtocolMessageType('ExecutionInfoDTO', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTIONINFODTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ExecutionInfoDTO)
  })
_sym_db.RegisterMessage(ExecutionInfoDTO)

RyuManagersInfoDTO = _reflection.GeneratedProtocolMessageType('RyuManagersInfoDTO', (_message.Message,), {
  'DESCRIPTOR' : _RYUMANAGERSINFODTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RyuManagersInfoDTO)
  })
_sym_db.RegisterMessage(RyuManagersInfoDTO)

RyuManagerStatusDTO = _reflection.GeneratedProtocolMessageType('RyuManagerStatusDTO', (_message.Message,), {
  'DESCRIPTOR' : _RYUMANAGERSTATUSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RyuManagerStatusDTO)
  })
_sym_db.RegisterMessage(RyuManagerStatusDTO)

HostManagersInfoDTO = _reflection.GeneratedProtocolMessageType('HostManagersInfoDTO', (_message.Message,), {
  'DESCRIPTOR' : _HOSTMANAGERSINFODTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:HostManagersInfoDTO)
  })
_sym_db.RegisterMessage(HostManagersInfoDTO)

HostManagerStatusesDTO = _reflection.GeneratedProtocolMessageType('HostManagerStatusesDTO', (_message.Message,), {
  'DESCRIPTOR' : _HOSTMANAGERSTATUSESDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:HostManagerStatusesDTO)
  })
_sym_db.RegisterMessage(HostManagerStatusesDTO)

HostManagerStatusDTO = _reflection.GeneratedProtocolMessageType('HostManagerStatusDTO', (_message.Message,), {
  'DESCRIPTOR' : _HOSTMANAGERSTATUSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:HostManagerStatusDTO)
  })
_sym_db.RegisterMessage(HostManagerStatusDTO)

KafkaManagersInfoDTO = _reflection.GeneratedProtocolMessageType('KafkaManagersInfoDTO', (_message.Message,), {
  'DESCRIPTOR' : _KAFKAMANAGERSINFODTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:KafkaManagersInfoDTO)
  })
_sym_db.RegisterMessage(KafkaManagersInfoDTO)

KafkaStatusDTO = _reflection.GeneratedProtocolMessageType('KafkaStatusDTO', (_message.Message,), {
  'DESCRIPTOR' : _KAFKASTATUSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:KafkaStatusDTO)
  })
_sym_db.RegisterMessage(KafkaStatusDTO)

OSSECIdsManagersInfoDTO = _reflection.GeneratedProtocolMessageType('OSSECIdsManagersInfoDTO', (_message.Message,), {
  'DESCRIPTOR' : _OSSECIDSMANAGERSINFODTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:OSSECIdsManagersInfoDTO)
  })
_sym_db.RegisterMessage(OSSECIdsManagersInfoDTO)

OSSECIdsStatusDTO = _reflection.GeneratedProtocolMessageType('OSSECIdsStatusDTO', (_message.Message,), {
  'DESCRIPTOR' : _OSSECIDSSTATUSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:OSSECIdsStatusDTO)
  })
_sym_db.RegisterMessage(OSSECIdsStatusDTO)

SnortIdsManagersInfoDTO = _reflection.GeneratedProtocolMessageType('SnortIdsManagersInfoDTO', (_message.Message,), {
  'DESCRIPTOR' : _SNORTIDSMANAGERSINFODTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:SnortIdsManagersInfoDTO)
  })
_sym_db.RegisterMessage(SnortIdsManagersInfoDTO)

SnortIdsStatusDTO = _reflection.GeneratedProtocolMessageType('SnortIdsStatusDTO', (_message.Message,), {
  'DESCRIPTOR' : _SNORTIDSSTATUSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:SnortIdsStatusDTO)
  })
_sym_db.RegisterMessage(SnortIdsStatusDTO)

GetExecutionInfoMsg = _reflection.GeneratedProtocolMessageType('GetExecutionInfoMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETEXECUTIONINFOMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetExecutionInfoMsg)
  })
_sym_db.RegisterMessage(GetExecutionInfoMsg)

StopContainersOfExecutionMsg = _reflection.GeneratedProtocolMessageType('StopContainersOfExecutionMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPCONTAINERSOFEXECUTIONMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopContainersOfExecutionMsg)
  })
_sym_db.RegisterMessage(StopContainersOfExecutionMsg)

RunContainerMsg = _reflection.GeneratedProtocolMessageType('RunContainerMsg', (_message.Message,), {
  'DESCRIPTOR' : _RUNCONTAINERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RunContainerMsg)
  })
_sym_db.RegisterMessage(RunContainerMsg)

StartContainersOfExecutionMsg = _reflection.GeneratedProtocolMessageType('StartContainersOfExecutionMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTCONTAINERSOFEXECUTIONMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartContainersOfExecutionMsg)
  })
_sym_db.RegisterMessage(StartContainersOfExecutionMsg)

GetElkManagersInfoMsg = _reflection.GeneratedProtocolMessageType('GetElkManagersInfoMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETELKMANAGERSINFOMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetElkManagersInfoMsg)
  })
_sym_db.RegisterMessage(GetElkManagersInfoMsg)

ElkManagersInfoDTO = _reflection.GeneratedProtocolMessageType('ElkManagersInfoDTO', (_message.Message,), {
  'DESCRIPTOR' : _ELKMANAGERSINFODTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ElkManagersInfoDTO)
  })
_sym_db.RegisterMessage(ElkManagersInfoDTO)

StopLogstashServiceMsg = _reflection.GeneratedProtocolMessageType('StopLogstashServiceMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPLOGSTASHSERVICEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopLogstashServiceMsg)
  })
_sym_db.RegisterMessage(StopLogstashServiceMsg)

StartLogstashServiceMsg = _reflection.GeneratedProtocolMessageType('StartLogstashServiceMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTLOGSTASHSERVICEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartLogstashServiceMsg)
  })
_sym_db.RegisterMessage(StartLogstashServiceMsg)

StopKibanaServiceMsg = _reflection.GeneratedProtocolMessageType('StopKibanaServiceMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPKIBANASERVICEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopKibanaServiceMsg)
  })
_sym_db.RegisterMessage(StopKibanaServiceMsg)

StartKibanaServiceMsg = _reflection.GeneratedProtocolMessageType('StartKibanaServiceMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTKIBANASERVICEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartKibanaServiceMsg)
  })
_sym_db.RegisterMessage(StartKibanaServiceMsg)

StopElasticServiceMsg = _reflection.GeneratedProtocolMessageType('StopElasticServiceMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPELASTICSERVICEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopElasticServiceMsg)
  })
_sym_db.RegisterMessage(StopElasticServiceMsg)

StartElasticServiceMsg = _reflection.GeneratedProtocolMessageType('StartElasticServiceMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTELASTICSERVICEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartElasticServiceMsg)
  })
_sym_db.RegisterMessage(StartElasticServiceMsg)

StopElkStackMsg = _reflection.GeneratedProtocolMessageType('StopElkStackMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPELKSTACKMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopElkStackMsg)
  })
_sym_db.RegisterMessage(StopElkStackMsg)

ElkStatusDTO = _reflection.GeneratedProtocolMessageType('ElkStatusDTO', (_message.Message,), {
  'DESCRIPTOR' : _ELKSTATUSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ElkStatusDTO)
  })
_sym_db.RegisterMessage(ElkStatusDTO)

GetElkStackStatusMsg = _reflection.GeneratedProtocolMessageType('GetElkStackStatusMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETELKSTACKSTATUSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetElkStackStatusMsg)
  })
_sym_db.RegisterMessage(GetElkStackStatusMsg)

StopElkManagerMsg = _reflection.GeneratedProtocolMessageType('StopElkManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPELKMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopElkManagerMsg)
  })
_sym_db.RegisterMessage(StopElkManagerMsg)

StartElkManagerMsg = _reflection.GeneratedProtocolMessageType('StartElkManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTELKMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartElkManagerMsg)
  })
_sym_db.RegisterMessage(StartElkManagerMsg)

GetDockerStatsManagersInfoMsg = _reflection.GeneratedProtocolMessageType('GetDockerStatsManagersInfoMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETDOCKERSTATSMANAGERSINFOMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetDockerStatsManagersInfoMsg)
  })
_sym_db.RegisterMessage(GetDockerStatsManagersInfoMsg)

DockerStatsManagersInfoDTO = _reflection.GeneratedProtocolMessageType('DockerStatsManagersInfoDTO', (_message.Message,), {
  'DESCRIPTOR' : _DOCKERSTATSMANAGERSINFODTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:DockerStatsManagersInfoDTO)
  })
_sym_db.RegisterMessage(DockerStatsManagersInfoDTO)

RemoveAllDockerNetworksMsg = _reflection.GeneratedProtocolMessageType('RemoveAllDockerNetworksMsg', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEALLDOCKERNETWORKSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RemoveAllDockerNetworksMsg)
  })
_sym_db.RegisterMessage(RemoveAllDockerNetworksMsg)

RemoveDockerNetworksMsg = _reflection.GeneratedProtocolMessageType('RemoveDockerNetworksMsg', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDOCKERNETWORKSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RemoveDockerNetworksMsg)
  })
_sym_db.RegisterMessage(RemoveDockerNetworksMsg)

DockerStatsMonitorStatusDTO = _reflection.GeneratedProtocolMessageType('DockerStatsMonitorStatusDTO', (_message.Message,), {
  'DESCRIPTOR' : _DOCKERSTATSMONITORSTATUSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:DockerStatsMonitorStatusDTO)
  })
_sym_db.RegisterMessage(DockerStatsMonitorStatusDTO)

GetDockerStatsManagerStatusMsg = _reflection.GeneratedProtocolMessageType('GetDockerStatsManagerStatusMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETDOCKERSTATSMANAGERSTATUSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetDockerStatsManagerStatusMsg)
  })
_sym_db.RegisterMessage(GetDockerStatsManagerStatusMsg)

StopDockerStatsManagerThreadMsg = _reflection.GeneratedProtocolMessageType('StopDockerStatsManagerThreadMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPDOCKERSTATSMANAGERTHREADMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopDockerStatsManagerThreadMsg)
  })
_sym_db.RegisterMessage(StopDockerStatsManagerThreadMsg)

CreateEmulationNetworksMsg = _reflection.GeneratedProtocolMessageType('CreateEmulationNetworksMsg', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEMULATIONNETWORKSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:CreateEmulationNetworksMsg)
  })
_sym_db.RegisterMessage(CreateEmulationNetworksMsg)

ListAllStoppedContainersMsg = _reflection.GeneratedProtocolMessageType('ListAllStoppedContainersMsg', (_message.Message,), {
  'DESCRIPTOR' : _LISTALLSTOPPEDCONTAINERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ListAllStoppedContainersMsg)
  })
_sym_db.RegisterMessage(ListAllStoppedContainersMsg)

StoppedContainersDTO = _reflection.GeneratedProtocolMessageType('StoppedContainersDTO', (_message.Message,), {
  'DESCRIPTOR' : _STOPPEDCONTAINERSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StoppedContainersDTO)
  })
_sym_db.RegisterMessage(StoppedContainersDTO)

ListAllRunningEmulationsMsg = _reflection.GeneratedProtocolMessageType('ListAllRunningEmulationsMsg', (_message.Message,), {
  'DESCRIPTOR' : _LISTALLRUNNINGEMULATIONSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ListAllRunningEmulationsMsg)
  })
_sym_db.RegisterMessage(ListAllRunningEmulationsMsg)

RunningEmulationsDTO = _reflection.GeneratedProtocolMessageType('RunningEmulationsDTO', (_message.Message,), {
  'DESCRIPTOR' : _RUNNINGEMULATIONSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RunningEmulationsDTO)
  })
_sym_db.RegisterMessage(RunningEmulationsDTO)

ListAllRunningContainersMsg = _reflection.GeneratedProtocolMessageType('ListAllRunningContainersMsg', (_message.Message,), {
  'DESCRIPTOR' : _LISTALLRUNNINGCONTAINERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ListAllRunningContainersMsg)
  })
_sym_db.RegisterMessage(ListAllRunningContainersMsg)

RunningContainersDTO = _reflection.GeneratedProtocolMessageType('RunningContainersDTO', (_message.Message,), {
  'DESCRIPTOR' : _RUNNINGCONTAINERSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RunningContainersDTO)
  })
_sym_db.RegisterMessage(RunningContainersDTO)

DockerContainerDTO = _reflection.GeneratedProtocolMessageType('DockerContainerDTO', (_message.Message,), {
  'DESCRIPTOR' : _DOCKERCONTAINERDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:DockerContainerDTO)
  })
_sym_db.RegisterMessage(DockerContainerDTO)

StartContainerMsg = _reflection.GeneratedProtocolMessageType('StartContainerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTCONTAINERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartContainerMsg)
  })
_sym_db.RegisterMessage(StartContainerMsg)

StartAllStoppedContainersMsg = _reflection.GeneratedProtocolMessageType('StartAllStoppedContainersMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTALLSTOPPEDCONTAINERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartAllStoppedContainersMsg)
  })
_sym_db.RegisterMessage(StartAllStoppedContainersMsg)

ListAllDockerNetworksMsg = _reflection.GeneratedProtocolMessageType('ListAllDockerNetworksMsg', (_message.Message,), {
  'DESCRIPTOR' : _LISTALLDOCKERNETWORKSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ListAllDockerNetworksMsg)
  })
_sym_db.RegisterMessage(ListAllDockerNetworksMsg)

DockerNetworksDTO = _reflection.GeneratedProtocolMessageType('DockerNetworksDTO', (_message.Message,), {
  'DESCRIPTOR' : _DOCKERNETWORKSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:DockerNetworksDTO)
  })
_sym_db.RegisterMessage(DockerNetworksDTO)

ContainerImagesDTO = _reflection.GeneratedProtocolMessageType('ContainerImagesDTO', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERIMAGESDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ContainerImagesDTO)
  })
_sym_db.RegisterMessage(ContainerImagesDTO)

ContainerImageDTO = _reflection.GeneratedProtocolMessageType('ContainerImageDTO', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERIMAGEDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ContainerImageDTO)
  })
_sym_db.RegisterMessage(ContainerImageDTO)

ListAllContainerImagesMsg = _reflection.GeneratedProtocolMessageType('ListAllContainerImagesMsg', (_message.Message,), {
  'DESCRIPTOR' : _LISTALLCONTAINERIMAGESMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ListAllContainerImagesMsg)
  })
_sym_db.RegisterMessage(ListAllContainerImagesMsg)

RemoveContainerImageMsg = _reflection.GeneratedProtocolMessageType('RemoveContainerImageMsg', (_message.Message,), {
  'DESCRIPTOR' : _REMOVECONTAINERIMAGEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RemoveContainerImageMsg)
  })
_sym_db.RegisterMessage(RemoveContainerImageMsg)

RemoveAllContainerImagesMsg = _reflection.GeneratedProtocolMessageType('RemoveAllContainerImagesMsg', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEALLCONTAINERIMAGESMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RemoveAllContainerImagesMsg)
  })
_sym_db.RegisterMessage(RemoveAllContainerImagesMsg)

RemoveAllStoppedContainersMsg = _reflection.GeneratedProtocolMessageType('RemoveAllStoppedContainersMsg', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEALLSTOPPEDCONTAINERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RemoveAllStoppedContainersMsg)
  })
_sym_db.RegisterMessage(RemoveAllStoppedContainersMsg)

RemoveContainerMsg = _reflection.GeneratedProtocolMessageType('RemoveContainerMsg', (_message.Message,), {
  'DESCRIPTOR' : _REMOVECONTAINERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:RemoveContainerMsg)
  })
_sym_db.RegisterMessage(RemoveContainerMsg)

StopContainerMsg = _reflection.GeneratedProtocolMessageType('StopContainerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPCONTAINERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopContainerMsg)
  })
_sym_db.RegisterMessage(StopContainerMsg)

StopAllRunningContainersMsg = _reflection.GeneratedProtocolMessageType('StopAllRunningContainersMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPALLRUNNINGCONTAINERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopAllRunningContainersMsg)
  })
_sym_db.RegisterMessage(StopAllRunningContainersMsg)

GetTrafficManagersInfoMsg = _reflection.GeneratedProtocolMessageType('GetTrafficManagersInfoMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETTRAFFICMANAGERSINFOMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetTrafficManagersInfoMsg)
  })
_sym_db.RegisterMessage(GetTrafficManagersInfoMsg)

TrafficManagersInfoDTO = _reflection.GeneratedProtocolMessageType('TrafficManagersInfoDTO', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICMANAGERSINFODTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:TrafficManagersInfoDTO)
  })
_sym_db.RegisterMessage(TrafficManagersInfoDTO)

TrafficManagerInfoDTO = _reflection.GeneratedProtocolMessageType('TrafficManagerInfoDTO', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICMANAGERINFODTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:TrafficManagerInfoDTO)
  })
_sym_db.RegisterMessage(TrafficManagerInfoDTO)

ClientManagersInfoDTO = _reflection.GeneratedProtocolMessageType('ClientManagersInfoDTO', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTMANAGERSINFODTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ClientManagersInfoDTO)
  })
_sym_db.RegisterMessage(ClientManagersInfoDTO)

GetClientManagersInfoMsg = _reflection.GeneratedProtocolMessageType('GetClientManagersInfoMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETCLIENTMANAGERSINFOMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetClientManagersInfoMsg)
  })
_sym_db.RegisterMessage(GetClientManagersInfoMsg)

StartTrafficGeneratorMsg = _reflection.GeneratedProtocolMessageType('StartTrafficGeneratorMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTTRAFFICGENERATORMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartTrafficGeneratorMsg)
  })
_sym_db.RegisterMessage(StartTrafficGeneratorMsg)

StopTrafficGeneratorMsg = _reflection.GeneratedProtocolMessageType('StopTrafficGeneratorMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPTRAFFICGENERATORMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopTrafficGeneratorMsg)
  })
_sym_db.RegisterMessage(StopTrafficGeneratorMsg)

StopTrafficGeneratorsMsg = _reflection.GeneratedProtocolMessageType('StopTrafficGeneratorsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPTRAFFICGENERATORSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopTrafficGeneratorsMsg)
  })
_sym_db.RegisterMessage(StopTrafficGeneratorsMsg)

GetNumClientsDTO = _reflection.GeneratedProtocolMessageType('GetNumClientsDTO', (_message.Message,), {
  'DESCRIPTOR' : _GETNUMCLIENTSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetNumClientsDTO)
  })
_sym_db.RegisterMessage(GetNumClientsDTO)

GetNumActiveClientsMsg = _reflection.GeneratedProtocolMessageType('GetNumActiveClientsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETNUMACTIVECLIENTSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetNumActiveClientsMsg)
  })
_sym_db.RegisterMessage(GetNumActiveClientsMsg)

StopClientPopulationMsg = _reflection.GeneratedProtocolMessageType('StopClientPopulationMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPCLIENTPOPULATIONMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopClientPopulationMsg)
  })
_sym_db.RegisterMessage(StopClientPopulationMsg)

StopClientManagerMsg = _reflection.GeneratedProtocolMessageType('StopClientManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPCLIENTMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopClientManagerMsg)
  })
_sym_db.RegisterMessage(StopClientManagerMsg)

StartClientManagerMsg = _reflection.GeneratedProtocolMessageType('StartClientManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTCLIENTMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartClientManagerMsg)
  })
_sym_db.RegisterMessage(StartClientManagerMsg)

StopTrafficManagersMsg = _reflection.GeneratedProtocolMessageType('StopTrafficManagersMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPTRAFFICMANAGERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopTrafficManagersMsg)
  })
_sym_db.RegisterMessage(StopTrafficManagersMsg)

StopTrafficManagerMsg = _reflection.GeneratedProtocolMessageType('StopTrafficManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPTRAFFICMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopTrafficManagerMsg)
  })
_sym_db.RegisterMessage(StopTrafficManagerMsg)

StartTrafficManagerMsg = _reflection.GeneratedProtocolMessageType('StartTrafficManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTTRAFFICMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartTrafficManagerMsg)
  })
_sym_db.RegisterMessage(StartTrafficManagerMsg)

CleanAllExecutionsMsg = _reflection.GeneratedProtocolMessageType('CleanAllExecutionsMsg', (_message.Message,), {
  'DESCRIPTOR' : _CLEANALLEXECUTIONSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:CleanAllExecutionsMsg)
  })
_sym_db.RegisterMessage(CleanAllExecutionsMsg)

StopAllExecutionsMsg = _reflection.GeneratedProtocolMessageType('StopAllExecutionsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPALLEXECUTIONSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopAllExecutionsMsg)
  })
_sym_db.RegisterMessage(StopAllExecutionsMsg)

StopExecutionMsg = _reflection.GeneratedProtocolMessageType('StopExecutionMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPEXECUTIONMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopExecutionMsg)
  })
_sym_db.RegisterMessage(StopExecutionMsg)

CleanExecutionMsg = _reflection.GeneratedProtocolMessageType('CleanExecutionMsg', (_message.Message,), {
  'DESCRIPTOR' : _CLEANEXECUTIONMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:CleanExecutionMsg)
  })
_sym_db.RegisterMessage(CleanExecutionMsg)

StopAllExecutionsOfEmulationMsg = _reflection.GeneratedProtocolMessageType('StopAllExecutionsOfEmulationMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPALLEXECUTIONSOFEMULATIONMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopAllExecutionsOfEmulationMsg)
  })
_sym_db.RegisterMessage(StopAllExecutionsOfEmulationMsg)

CleanAllExecutionsOfEmulationMsg = _reflection.GeneratedProtocolMessageType('CleanAllExecutionsOfEmulationMsg', (_message.Message,), {
  'DESCRIPTOR' : _CLEANALLEXECUTIONSOFEMULATIONMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:CleanAllExecutionsOfEmulationMsg)
  })
_sym_db.RegisterMessage(CleanAllExecutionsOfEmulationMsg)

GetCsleLogFilesMsg = _reflection.GeneratedProtocolMessageType('GetCsleLogFilesMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETCSLELOGFILESMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetCsleLogFilesMsg)
  })
_sym_db.RegisterMessage(GetCsleLogFilesMsg)

GetLogFileMsg = _reflection.GeneratedProtocolMessageType('GetLogFileMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETLOGFILEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetLogFileMsg)
  })
_sym_db.RegisterMessage(GetLogFileMsg)

StartContainersInExecutionMsg = _reflection.GeneratedProtocolMessageType('StartContainersInExecutionMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTCONTAINERSINEXECUTIONMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartContainersInExecutionMsg)
  })
_sym_db.RegisterMessage(StartContainersInExecutionMsg)

AttachContainersToNetworksInExecutionMsg = _reflection.GeneratedProtocolMessageType('AttachContainersToNetworksInExecutionMsg', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHCONTAINERSTONETWORKSINEXECUTIONMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:AttachContainersToNetworksInExecutionMsg)
  })
_sym_db.RegisterMessage(AttachContainersToNetworksInExecutionMsg)

InstallLibrariesMsg = _reflection.GeneratedProtocolMessageType('InstallLibrariesMsg', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLLIBRARIESMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:InstallLibrariesMsg)
  })
_sym_db.RegisterMessage(InstallLibrariesMsg)

ApplyKafkaConfigMsg = _reflection.GeneratedProtocolMessageType('ApplyKafkaConfigMsg', (_message.Message,), {
  'DESCRIPTOR' : _APPLYKAFKACONFIGMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ApplyKafkaConfigMsg)
  })
_sym_db.RegisterMessage(ApplyKafkaConfigMsg)

StartSdnControllerMsg = _reflection.GeneratedProtocolMessageType('StartSdnControllerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTSDNCONTROLLERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartSdnControllerMsg)
  })
_sym_db.RegisterMessage(StartSdnControllerMsg)

ApplyResouceConstraintsMsg = _reflection.GeneratedProtocolMessageType('ApplyResouceConstraintsMsg', (_message.Message,), {
  'DESCRIPTOR' : _APPLYRESOUCECONSTRAINTSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ApplyResouceConstraintsMsg)
  })
_sym_db.RegisterMessage(ApplyResouceConstraintsMsg)

CreateOvsSwitchesMsg = _reflection.GeneratedProtocolMessageType('CreateOvsSwitchesMsg', (_message.Message,), {
  'DESCRIPTOR' : _CREATEOVSSWITCHESMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:CreateOvsSwitchesMsg)
  })
_sym_db.RegisterMessage(CreateOvsSwitchesMsg)

PingExecutionMsg = _reflection.GeneratedProtocolMessageType('PingExecutionMsg', (_message.Message,), {
  'DESCRIPTOR' : _PINGEXECUTIONMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:PingExecutionMsg)
  })
_sym_db.RegisterMessage(PingExecutionMsg)

ConfigureOvsMsg = _reflection.GeneratedProtocolMessageType('ConfigureOvsMsg', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGUREOVSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ConfigureOvsMsg)
  })
_sym_db.RegisterMessage(ConfigureOvsMsg)

StartSdnControllerMonitorMsg = _reflection.GeneratedProtocolMessageType('StartSdnControllerMonitorMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTSDNCONTROLLERMONITORMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartSdnControllerMonitorMsg)
  })
_sym_db.RegisterMessage(StartSdnControllerMonitorMsg)

CreateUsersMsg = _reflection.GeneratedProtocolMessageType('CreateUsersMsg', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:CreateUsersMsg)
  })
_sym_db.RegisterMessage(CreateUsersMsg)

CreateVulnsMsg = _reflection.GeneratedProtocolMessageType('CreateVulnsMsg', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVULNSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:CreateVulnsMsg)
  })
_sym_db.RegisterMessage(CreateVulnsMsg)

CreateFlagsMsg = _reflection.GeneratedProtocolMessageType('CreateFlagsMsg', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFLAGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:CreateFlagsMsg)
  })
_sym_db.RegisterMessage(CreateFlagsMsg)

CreateTopologyMsg = _reflection.GeneratedProtocolMessageType('CreateTopologyMsg', (_message.Message,), {
  'DESCRIPTOR' : _CREATETOPOLOGYMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:CreateTopologyMsg)
  })
_sym_db.RegisterMessage(CreateTopologyMsg)

StartTrafficManagersMsg = _reflection.GeneratedProtocolMessageType('StartTrafficManagersMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTTRAFFICMANAGERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartTrafficManagersMsg)
  })
_sym_db.RegisterMessage(StartTrafficManagersMsg)

StartTrafficGeneratorsMsg = _reflection.GeneratedProtocolMessageType('StartTrafficGeneratorsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTTRAFFICGENERATORSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartTrafficGeneratorsMsg)
  })
_sym_db.RegisterMessage(StartTrafficGeneratorsMsg)

StartClientPopulationMsg = _reflection.GeneratedProtocolMessageType('StartClientPopulationMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTCLIENTPOPULATIONMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartClientPopulationMsg)
  })
_sym_db.RegisterMessage(StartClientPopulationMsg)

StartKafkaClientProducerMsg = _reflection.GeneratedProtocolMessageType('StartKafkaClientProducerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTKAFKACLIENTPRODUCERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartKafkaClientProducerMsg)
  })
_sym_db.RegisterMessage(StartKafkaClientProducerMsg)

StopKafkaClientProducerMsg = _reflection.GeneratedProtocolMessageType('StopKafkaClientProducerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPKAFKACLIENTPRODUCERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopKafkaClientProducerMsg)
  })
_sym_db.RegisterMessage(StopKafkaClientProducerMsg)

StartSnortIdsesMsg = _reflection.GeneratedProtocolMessageType('StartSnortIdsesMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTSNORTIDSESMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartSnortIdsesMsg)
  })
_sym_db.RegisterMessage(StartSnortIdsesMsg)

StartSnortIdsesMonitorThreadsMsg = _reflection.GeneratedProtocolMessageType('StartSnortIdsesMonitorThreadsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTSNORTIDSESMONITORTHREADSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartSnortIdsesMonitorThreadsMsg)
  })
_sym_db.RegisterMessage(StartSnortIdsesMonitorThreadsMsg)

StartOSSECIdsesMsg = _reflection.GeneratedProtocolMessageType('StartOSSECIdsesMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTOSSECIDSESMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartOSSECIdsesMsg)
  })
_sym_db.RegisterMessage(StartOSSECIdsesMsg)

StartOSSECIdsesMonitorThreadsMsg = _reflection.GeneratedProtocolMessageType('StartOSSECIdsesMonitorThreadsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTOSSECIDSESMONITORTHREADSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartOSSECIdsesMonitorThreadsMsg)
  })
_sym_db.RegisterMessage(StartOSSECIdsesMonitorThreadsMsg)

StartElkStackMsg = _reflection.GeneratedProtocolMessageType('StartElkStackMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTELKSTACKMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartElkStackMsg)
  })
_sym_db.RegisterMessage(StartElkStackMsg)

StartHostManagersMsg = _reflection.GeneratedProtocolMessageType('StartHostManagersMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTHOSTMANAGERSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartHostManagersMsg)
  })
_sym_db.RegisterMessage(StartHostManagersMsg)

ApplyFileBeatConfigsMsg = _reflection.GeneratedProtocolMessageType('ApplyFileBeatConfigsMsg', (_message.Message,), {
  'DESCRIPTOR' : _APPLYFILEBEATCONFIGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ApplyFileBeatConfigsMsg)
  })
_sym_db.RegisterMessage(ApplyFileBeatConfigsMsg)

ApplyPacketBeatConfigsMsg = _reflection.GeneratedProtocolMessageType('ApplyPacketBeatConfigsMsg', (_message.Message,), {
  'DESCRIPTOR' : _APPLYPACKETBEATCONFIGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ApplyPacketBeatConfigsMsg)
  })
_sym_db.RegisterMessage(ApplyPacketBeatConfigsMsg)

ApplyMetricBeatConfigsMsg = _reflection.GeneratedProtocolMessageType('ApplyMetricBeatConfigsMsg', (_message.Message,), {
  'DESCRIPTOR' : _APPLYMETRICBEATCONFIGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ApplyMetricBeatConfigsMsg)
  })
_sym_db.RegisterMessage(ApplyMetricBeatConfigsMsg)

ApplyHeartBeatConfigsMsg = _reflection.GeneratedProtocolMessageType('ApplyHeartBeatConfigsMsg', (_message.Message,), {
  'DESCRIPTOR' : _APPLYHEARTBEATCONFIGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ApplyHeartBeatConfigsMsg)
  })
_sym_db.RegisterMessage(ApplyHeartBeatConfigsMsg)

StartFileBeatsMsg = _reflection.GeneratedProtocolMessageType('StartFileBeatsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTFILEBEATSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartFileBeatsMsg)
  })
_sym_db.RegisterMessage(StartFileBeatsMsg)

StartPacketBeatsMsg = _reflection.GeneratedProtocolMessageType('StartPacketBeatsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTPACKETBEATSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartPacketBeatsMsg)
  })
_sym_db.RegisterMessage(StartPacketBeatsMsg)

StartMetricBeatsMsg = _reflection.GeneratedProtocolMessageType('StartMetricBeatsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTMETRICBEATSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartMetricBeatsMsg)
  })
_sym_db.RegisterMessage(StartMetricBeatsMsg)

StartHeartBeatsMsg = _reflection.GeneratedProtocolMessageType('StartHeartBeatsMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTHEARTBEATSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartHeartBeatsMsg)
  })
_sym_db.RegisterMessage(StartHeartBeatsMsg)

GetDockerStatsManagerLogsMsg = _reflection.GeneratedProtocolMessageType('GetDockerStatsManagerLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETDOCKERSTATSMANAGERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetDockerStatsManagerLogsMsg)
  })
_sym_db.RegisterMessage(GetDockerStatsManagerLogsMsg)

GetPrometheusLogsMsg = _reflection.GeneratedProtocolMessageType('GetPrometheusLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETPROMETHEUSLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetPrometheusLogsMsg)
  })
_sym_db.RegisterMessage(GetPrometheusLogsMsg)

GetNodeExporterLogsMsg = _reflection.GeneratedProtocolMessageType('GetNodeExporterLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETNODEEXPORTERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetNodeExporterLogsMsg)
  })
_sym_db.RegisterMessage(GetNodeExporterLogsMsg)

GetCAdvisorLogsMsg = _reflection.GeneratedProtocolMessageType('GetCAdvisorLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETCADVISORLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetCAdvisorLogsMsg)
  })
_sym_db.RegisterMessage(GetCAdvisorLogsMsg)

GetPgAdminLogsMsg = _reflection.GeneratedProtocolMessageType('GetPgAdminLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETPGADMINLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetPgAdminLogsMsg)
  })
_sym_db.RegisterMessage(GetPgAdminLogsMsg)

GetGrafanaLogsMsg = _reflection.GeneratedProtocolMessageType('GetGrafanaLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETGRAFANALOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetGrafanaLogsMsg)
  })
_sym_db.RegisterMessage(GetGrafanaLogsMsg)

GetNginxLogsMsg = _reflection.GeneratedProtocolMessageType('GetNginxLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETNGINXLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetNginxLogsMsg)
  })
_sym_db.RegisterMessage(GetNginxLogsMsg)

GetDockerLogsMsg = _reflection.GeneratedProtocolMessageType('GetDockerLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETDOCKERLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetDockerLogsMsg)
  })
_sym_db.RegisterMessage(GetDockerLogsMsg)

GetPostgreSQLLogsMsg = _reflection.GeneratedProtocolMessageType('GetPostgreSQLLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTGRESQLLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetPostgreSQLLogsMsg)
  })
_sym_db.RegisterMessage(GetPostgreSQLLogsMsg)

GetFlaskLogsMsg = _reflection.GeneratedProtocolMessageType('GetFlaskLogsMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETFLASKLOGSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetFlaskLogsMsg)
  })
_sym_db.RegisterMessage(GetFlaskLogsMsg)

LogsDTO = _reflection.GeneratedProtocolMessageType('LogsDTO', (_message.Message,), {
  'DESCRIPTOR' : _LOGSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:LogsDTO)
  })
_sym_db.RegisterMessage(LogsDTO)

OperationOutcomeDTO = _reflection.GeneratedProtocolMessageType('OperationOutcomeDTO', (_message.Message,), {
  'DESCRIPTOR' : _OPERATIONOUTCOMEDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:OperationOutcomeDTO)
  })
_sym_db.RegisterMessage(OperationOutcomeDTO)

GetNodeStatusMsg = _reflection.GeneratedProtocolMessageType('GetNodeStatusMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETNODESTATUSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetNodeStatusMsg)
  })
_sym_db.RegisterMessage(GetNodeStatusMsg)

NodeStatusDTO = _reflection.GeneratedProtocolMessageType('NodeStatusDTO', (_message.Message,), {
  'DESCRIPTOR' : _NODESTATUSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:NodeStatusDTO)
  })
_sym_db.RegisterMessage(NodeStatusDTO)

ServiceStatusDTO = _reflection.GeneratedProtocolMessageType('ServiceStatusDTO', (_message.Message,), {
  'DESCRIPTOR' : _SERVICESTATUSDTO,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:ServiceStatusDTO)
  })
_sym_db.RegisterMessage(ServiceStatusDTO)

StartPostgreSQLMsg = _reflection.GeneratedProtocolMessageType('StartPostgreSQLMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTPOSTGRESQLMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartPostgreSQLMsg)
  })
_sym_db.RegisterMessage(StartPostgreSQLMsg)

StartCAdvisorMsg = _reflection.GeneratedProtocolMessageType('StartCAdvisorMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTCADVISORMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartCAdvisorMsg)
  })
_sym_db.RegisterMessage(StartCAdvisorMsg)

StartNodeExporterMsg = _reflection.GeneratedProtocolMessageType('StartNodeExporterMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTNODEEXPORTERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartNodeExporterMsg)
  })
_sym_db.RegisterMessage(StartNodeExporterMsg)

StartGrafanaMsg = _reflection.GeneratedProtocolMessageType('StartGrafanaMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTGRAFANAMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartGrafanaMsg)
  })
_sym_db.RegisterMessage(StartGrafanaMsg)

StartPrometheusMsg = _reflection.GeneratedProtocolMessageType('StartPrometheusMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTPROMETHEUSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartPrometheusMsg)
  })
_sym_db.RegisterMessage(StartPrometheusMsg)

StartPgAdminMsg = _reflection.GeneratedProtocolMessageType('StartPgAdminMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTPGADMINMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartPgAdminMsg)
  })
_sym_db.RegisterMessage(StartPgAdminMsg)

StartNginxMsg = _reflection.GeneratedProtocolMessageType('StartNginxMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTNGINXMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartNginxMsg)
  })
_sym_db.RegisterMessage(StartNginxMsg)

StartFlaskMsg = _reflection.GeneratedProtocolMessageType('StartFlaskMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTFLASKMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartFlaskMsg)
  })
_sym_db.RegisterMessage(StartFlaskMsg)

StartDockerStatsManagerMsg = _reflection.GeneratedProtocolMessageType('StartDockerStatsManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTDOCKERSTATSMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartDockerStatsManagerMsg)
  })
_sym_db.RegisterMessage(StartDockerStatsManagerMsg)

StartDockerStatsManagerThreadMsg = _reflection.GeneratedProtocolMessageType('StartDockerStatsManagerThreadMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTDOCKERSTATSMANAGERTHREADMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartDockerStatsManagerThreadMsg)
  })
_sym_db.RegisterMessage(StartDockerStatsManagerThreadMsg)

StartDockerEngineMsg = _reflection.GeneratedProtocolMessageType('StartDockerEngineMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTDOCKERENGINEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartDockerEngineMsg)
  })
_sym_db.RegisterMessage(StartDockerEngineMsg)

StopPostgreSQLMsg = _reflection.GeneratedProtocolMessageType('StopPostgreSQLMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPPOSTGRESQLMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopPostgreSQLMsg)
  })
_sym_db.RegisterMessage(StopPostgreSQLMsg)

StopCAdvisorMsg = _reflection.GeneratedProtocolMessageType('StopCAdvisorMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPCADVISORMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopCAdvisorMsg)
  })
_sym_db.RegisterMessage(StopCAdvisorMsg)

StopNodeExporterMsg = _reflection.GeneratedProtocolMessageType('StopNodeExporterMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPNODEEXPORTERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopNodeExporterMsg)
  })
_sym_db.RegisterMessage(StopNodeExporterMsg)

StopGrafanaMsg = _reflection.GeneratedProtocolMessageType('StopGrafanaMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPGRAFANAMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopGrafanaMsg)
  })
_sym_db.RegisterMessage(StopGrafanaMsg)

StopPrometheusMsg = _reflection.GeneratedProtocolMessageType('StopPrometheusMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPPROMETHEUSMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopPrometheusMsg)
  })
_sym_db.RegisterMessage(StopPrometheusMsg)

StopPgAdminMsg = _reflection.GeneratedProtocolMessageType('StopPgAdminMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPPGADMINMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopPgAdminMsg)
  })
_sym_db.RegisterMessage(StopPgAdminMsg)

StopNginxMsg = _reflection.GeneratedProtocolMessageType('StopNginxMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPNGINXMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopNginxMsg)
  })
_sym_db.RegisterMessage(StopNginxMsg)

StopFlaskMsg = _reflection.GeneratedProtocolMessageType('StopFlaskMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPFLASKMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopFlaskMsg)
  })
_sym_db.RegisterMessage(StopFlaskMsg)

StopDockerStatsManagerMsg = _reflection.GeneratedProtocolMessageType('StopDockerStatsManagerMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPDOCKERSTATSMANAGERMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopDockerStatsManagerMsg)
  })
_sym_db.RegisterMessage(StopDockerStatsManagerMsg)

StopDockerEngineMsg = _reflection.GeneratedProtocolMessageType('StopDockerEngineMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPDOCKERENGINEMSG,
  '__module__' : 'cluster_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopDockerEngineMsg)
  })
_sym_db.RegisterMessage(StopDockerEngineMsg)

_CLUSTERMANAGER = DESCRIPTOR.services_by_name['ClusterManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STOPPIDMSG._serialized_start=25
  _STOPPIDMSG._serialized_end=50
  _CHECKPIDMSG._serialized_start=52
  _CHECKPIDMSG._serialized_end=78
  _STARTSPARKSERVERMSG._serialized_start=80
  _STARTSPARKSERVERMSG._serialized_end=163
  _STOPSPARKSERVERMSG._serialized_start=165
  _STOPSPARKSERVERMSG._serialized_end=247
  _STARTSPARKSERVERSMSG._serialized_start=249
  _STARTSPARKSERVERSMSG._serialized_end=312
  _STOPSPARKSERVERSMSG._serialized_start=314
  _STOPSPARKSERVERSMSG._serialized_end=376
  _GETEXECUTIONTIMESERIESDATAMSG._serialized_start=378
  _GETEXECUTIONTIMESERIESDATAMSG._serialized_end=467
  _EMULATIONMETRICSTIMESERIESDTO._serialized_start=470
  _EMULATIONMETRICSTIMESERIESDTO._serialized_end=1911
  _AVGPORTSTATISTICDICT._serialized_start=1913
  _AVGPORTSTATISTICDICT._serialized_end=1984
  _AGGFLOWSTATISTICDICT._serialized_start=1986
  _AGGFLOWSTATISTICDICT._serialized_end=2057
  _AVGFLOWSTATISTICDICT._serialized_start=2059
  _AVGFLOWSTATISTICDICT._serialized_end=2130
  _PORTSTATISTICDICT._serialized_start=2132
  _PORTSTATISTICDICT._serialized_end=2197
  _FLOWSTATISTICDICT._serialized_start=2199
  _FLOWSTATISTICDICT._serialized_end=2264
  _OSSECIDSALERTCOUNTERSDICT._serialized_start=2266
  _OSSECIDSALERTCOUNTERSDICT._serialized_end=2347
  _HOSTMETRICSDICT._serialized_start=2349
  _HOSTMETRICSDICT._serialized_end=2414
  _DOCKERSTATSDICT._serialized_start=2416
  _DOCKERSTATSDICT._serialized_end=2477
  _AVGPORTSTATISTICDTO._serialized_start=2480
  _AVGPORTSTATISTICDTO._serialized_end=3052
  _AVGFLOWSTATISTICDTO._serialized_start=3055
  _AVGFLOWSTATISTICDTO._serialized_end=3326
  _AGGFLOWSTATISTICDTO._serialized_start=3329
  _AGGFLOWSTATISTICDTO._serialized_end=3467
  _PORTSTATISTICDTO._serialized_start=3470
  _PORTSTATISTICDTO._serialized_end=3973
  _FLOWSTATISTICDTO._serialized_start=3976
  _FLOWSTATISTICDTO._serialized_end=4268
  _OSSECIDSALERTCOUNTERSDTO._serialized_start=4271
  _OSSECIDSALERTCOUNTERSDTO._serialized_end=4468
  _SNORTIDSALERTCOUNTERSDTO._serialized_start=4471
  _SNORTIDSALERTCOUNTERSDTO._serialized_end=4652
  _SNORTIDSIPALERTCOUNTERSDICT._serialized_start=4654
  _SNORTIDSIPALERTCOUNTERSDICT._serialized_end=4739
  _SNORTIDSALERTCOUNTERSDICT._serialized_start=4741
  _SNORTIDSALERTCOUNTERSDICT._serialized_end=4822
  _SNORTIDSRULECOUNTERSDICT._serialized_start=4824
  _SNORTIDSRULECOUNTERSDICT._serialized_end=4903
  _SNORTIDSIPALERTCOUNTERSDTO._serialized_start=4906
  _SNORTIDSIPALERTCOUNTERSDTO._serialized_end=5107
  _SNORTIDSRULECOUNTERSDTO._serialized_start=5109
  _SNORTIDSRULECOUNTERSDTO._serialized_end=5203
  _EMULATIONATTACKERACTIONDTO._serialized_start=5206
  _EMULATIONATTACKERACTIONDTO._serialized_end=5450
  _EMULATIONDEFENDERACTIONDTO._serialized_start=5453
  _EMULATIONDEFENDERACTIONDTO._serialized_end=5656
  _HOSTMETRICSDATADTO._serialized_start=5659
  _HOSTMETRICSDATADTO._serialized_end=5865
  _DOCKERSTATSDTO._serialized_start=5868
  _DOCKERSTATSDTO._serialized_end=6116
  _CLIENTPOPULATIONMETRICSDTO._serialized_start=6118
  _CLIENTPOPULATIONMETRICSDTO._serialized_end=6227
  _GETCLUSTERMANAGERLOGSMSG._serialized_start=6229
  _GETCLUSTERMANAGERLOGSMSG._serialized_end=6255
  _GETCONTAINERLOGSMSG._serialized_start=6257
  _GETCONTAINERLOGSMSG._serialized_end=6340
  _GETCLIENTMANAGERLOGSMSG._serialized_start=6342
  _GETCLIENTMANAGERLOGSMSG._serialized_end=6408
  _GETKAFKAMANAGERLOGSMSG._serialized_start=6410
  _GETKAFKAMANAGERLOGSMSG._serialized_end=6475
  _GETKAFKALOGSMSG._serialized_start=6477
  _GETKAFKALOGSMSG._serialized_end=6535
  _GETSNORTIDSLOGSMSG._serialized_start=6537
  _GETSNORTIDSLOGSMSG._serialized_end=6619
  _GETSNORTIDSMANAGERLOGSMSG._serialized_start=6621
  _GETSNORTIDSMANAGERLOGSMSG._serialized_end=6710
  _GETOSSECIDSMANAGERLOGSMSG._serialized_start=6712
  _GETOSSECIDSMANAGERLOGSMSG._serialized_end=6801
  _GETOSSECIDSLOGSMSG._serialized_start=6803
  _GETOSSECIDSLOGSMSG._serialized_end=6885
  _GETHOSTMANAGERLOGSMSG._serialized_start=6887
  _GETHOSTMANAGERLOGSMSG._serialized_end=6972
  _GETTRAFFICMANAGERLOGSMSG._serialized_start=6974
  _GETTRAFFICMANAGERLOGSMSG._serialized_end=7062
  _GETELKMANAGERLOGSMSG._serialized_start=7064
  _GETELKMANAGERLOGSMSG._serialized_end=7127
  _GETELKLOGSMSG._serialized_start=7129
  _GETELKLOGSMSG._serialized_end=7185
  _GETRYUMANAGERLOGSMSG._serialized_start=7187
  _GETRYUMANAGERLOGSMSG._serialized_end=7250
  _GETRYUCONTROLLERLOGSMSG._serialized_start=7252
  _GETRYUCONTROLLERLOGSMSG._serialized_end=7318
  _STOPRYUMONITORTHREADMSG._serialized_start=7320
  _STOPRYUMONITORTHREADMSG._serialized_end=7386
  _STARTRYUMONITORTHREADMSG._serialized_start=7388
  _STARTRYUMONITORTHREADMSG._serialized_end=7455
  _STOPHOSTMONITORTHREADSMSG._serialized_start=7457
  _STOPHOSTMONITORTHREADSMSG._serialized_end=7525
  _STOPHOSTMONITORTHREADMSG._serialized_start=7527
  _STOPHOSTMONITORTHREADMSG._serialized_end=7615
  _REMOVEKIBANATUNNELMSG._serialized_start=7617
  _REMOVEKIBANATUNNELMSG._serialized_end=7681
  _CREATEKIBANATUNNELMSG._serialized_start=7683
  _CREATEKIBANATUNNELMSG._serialized_end=7747
  _LISTKIBANATUNNELSMSG._serialized_start=7749
  _LISTKIBANATUNNELSMSG._serialized_end=7771
  _KIBANATUNNELSDTO._serialized_start=7773
  _KIBANATUNNELSDTO._serialized_end=7826
  _KIBANATUNNELDTO._serialized_start=7828
  _KIBANATUNNELDTO._serialized_end=7912
  _REMOVERYUTUNNELMSG._serialized_start=7914
  _REMOVERYUTUNNELMSG._serialized_end=7975
  _CREATERYUTUNNELMSG._serialized_start=7977
  _CREATERYUTUNNELMSG._serialized_end=8038
  _LISTRYUTUNNELSMSG._serialized_start=8040
  _LISTRYUTUNNELSMSG._serialized_end=8059
  _RYUTUNNELSDTO._serialized_start=8061
  _RYUTUNNELSDTO._serialized_end=8108
  _RYUTUNNELDTO._serialized_start=8110
  _RYUTUNNELDTO._serialized_end=8191
  _SNORTIDSMONITORTHREADSTATUSESDTO._serialized_start=8193
  _SNORTIDSMONITORTHREADSTATUSESDTO._serialized_end=8273
  _GETSNORTIDSMANAGERSINFOMSG._serialized_start=8275
  _GETSNORTIDSMANAGERSINFOMSG._serialized_end=8344
  _GETSNORTIDSMONITORTHREADSTATUSESMSG._serialized_start=8346
  _GETSNORTIDSMONITORTHREADSTATUSESMSG._serialized_end=8424
  _STOPSNORTIDSMONITORTHREADSMSG._serialized_start=8426
  _STOPSNORTIDSMONITORTHREADSMSG._serialized_end=8498
  _STOPSNORTIDSMANAGERMSG._serialized_start=8500
  _STOPSNORTIDSMANAGERMSG._serialized_end=8586
  _STARTSNORTIDSMANAGERMSG._serialized_start=8588
  _STARTSNORTIDSMANAGERMSG._serialized_end=8675
  _STOPSNORTIDSMANAGERSMSG._serialized_start=8677
  _STOPSNORTIDSMANAGERSMSG._serialized_end=8743
  _STARTSNORTIDSMANAGERSMSG._serialized_start=8745
  _STARTSNORTIDSMANAGERSMSG._serialized_end=8812
  _STARTSNORTMSG._serialized_start=8814
  _STARTSNORTMSG._serialized_end=8891
  _STARTSNORTIDSMONITORTHREADMSG._serialized_start=8893
  _STARTSNORTIDSMONITORTHREADMSG._serialized_end=8986
  _STARTSNORTIDSMONITORTHREADSMSG._serialized_start=8988
  _STARTSNORTIDSMONITORTHREADSMSG._serialized_end=9061
  _STOPSNORTMSG._serialized_start=9063
  _STOPSNORTMSG._serialized_end=9139
  _STOPSNORTIDSMONITORTHREADMSG._serialized_start=9141
  _STOPSNORTIDSMONITORTHREADMSG._serialized_end=9233
  _STOPSNORTIDSESMSG._serialized_start=9235
  _STOPSNORTIDSESMSG._serialized_end=9295
  _STOPSNORTIDSESMONITORTHREADSMSG._serialized_start=9297
  _STOPSNORTIDSESMONITORTHREADSMSG._serialized_end=9371
  _GETRYUMANAGERSINFOMSG._serialized_start=9373
  _GETRYUMANAGERSINFOMSG._serialized_end=9437
  _STOPRYUMONITORSERVICEMSG._serialized_start=9439
  _STOPRYUMONITORSERVICEMSG._serialized_end=9506
  _STARTRYUMONITORSERVICEMSG._serialized_start=9508
  _STARTRYUMONITORSERVICEMSG._serialized_end=9576
  _STOPRYUSERVICEMSG._serialized_start=9578
  _STOPRYUSERVICEMSG._serialized_end=9638
  _STARTRYUSERVICEMSG._serialized_start=9640
  _STARTRYUSERVICEMSG._serialized_end=9701
  _GETRYUSERVICESTATUSMSG._serialized_start=9703
  _GETRYUSERVICESTATUSMSG._serialized_end=9768
  _STOPRYUMANAGERMSG._serialized_start=9770
  _STOPRYUMANAGERMSG._serialized_end=9830
  _STARTRYUMANAGERMSG._serialized_start=9832
  _STARTRYUMANAGERMSG._serialized_end=9893
  _GETOSSECIDSMANAGERSINFOMSG._serialized_start=9895
  _GETOSSECIDSMANAGERSINFOMSG._serialized_end=9964
  _OSSECIDSMONITORTHREADSTATUSESDTO._serialized_start=9966
  _OSSECIDSMONITORTHREADSTATUSESDTO._serialized_end=10046
  _GETOSSECIDSMONITORTHREADSTATUSESMSG._serialized_start=10048
  _GETOSSECIDSMONITORTHREADSTATUSESMSG._serialized_end=10126
  _STOPOSSECIDSMONITORTHREADSMSG._serialized_start=10128
  _STOPOSSECIDSMONITORTHREADSMSG._serialized_end=10200
  _STOPOSSECIDSMONITORTHREADMSG._serialized_start=10202
  _STOPOSSECIDSMONITORTHREADMSG._serialized_end=10294
  _STARTOSSECIDSMONITORTHREADMSG._serialized_start=10296
  _STARTOSSECIDSMONITORTHREADMSG._serialized_end=10389
  _STOPOSSECIDSMANAGER._serialized_start=10391
  _STOPOSSECIDSMANAGER._serialized_end=10474
  _STARTOSSECIDSMANAGER._serialized_start=10476
  _STARTOSSECIDSMANAGER._serialized_end=10560
  _STOPOSSECIDSMANAGERS._serialized_start=10562
  _STOPOSSECIDSMANAGERS._serialized_end=10625
  _STARTOSSECIDSMANAGERS._serialized_start=10627
  _STARTOSSECIDSMANAGERS._serialized_end=10691
  _STARTOSSECIDSMSG._serialized_start=10693
  _STARTOSSECIDSMSG._serialized_end=10773
  _STOPOSSECIDSMSG._serialized_start=10775
  _STOPOSSECIDSMSG._serialized_end=10854
  _STARTOSSECIDSESMSG._serialized_start=10856
  _STARTOSSECIDSESMSG._serialized_end=10917
  _STOPOSSECIDSESMSG._serialized_start=10919
  _STOPOSSECIDSESMSG._serialized_end=10979
  _GETKAFKAMANAGERSINFOMSG._serialized_start=10981
  _GETKAFKAMANAGERSINFOMSG._serialized_end=11047
  _STARTKAFKASERVERMSG._serialized_start=11049
  _STARTKAFKASERVERMSG._serialized_end=11111
  _STOPKAFKASERVERMSG._serialized_start=11113
  _STOPKAFKASERVERMSG._serialized_end=11174
  _GETKAFKAMANAGERSTATUSMSG._serialized_start=11176
  _GETKAFKAMANAGERSTATUSMSG._serialized_end=11243
  _CREATEKAFKATOPICSMSG._serialized_start=11245
  _CREATEKAFKATOPICSMSG._serialized_end=11308
  _STOPKAFKAMANAGERMSG._serialized_start=11310
  _STOPKAFKAMANAGERMSG._serialized_end=11372
  _STARTKAFKAMANAGERMSG._serialized_start=11374
  _STARTKAFKAMANAGERMSG._serialized_end=11437
  _GETHOSTMANAGERSINFOMSG._serialized_start=11439
  _GETHOSTMANAGERSINFOMSG._serialized_end=11504
  _GETHOSTMONITORTHREADSSTATUSESMSG._serialized_start=11506
  _GETHOSTMONITORTHREADSSTATUSESMSG._serialized_end=11581
  _APPLYFILEBEATCONFIGMSG._serialized_start=11583
  _APPLYFILEBEATCONFIGMSG._serialized_end=11669
  _APPLYPACKETBEATCONFIGMSG._serialized_start=11671
  _APPLYPACKETBEATCONFIGMSG._serialized_end=11759
  _APPLYMETRICBEATCONFIGMSG._serialized_start=11761
  _APPLYMETRICBEATCONFIGMSG._serialized_end=11849
  _APPLYHEARTBEATCONFIGMSG._serialized_start=11851
  _APPLYHEARTBEATCONFIGMSG._serialized_end=11938
  _STOPFILEBEATMSG._serialized_start=11940
  _STOPFILEBEATMSG._serialized_end=12019
  _STOPPACKETBEATMSG._serialized_start=12021
  _STOPPACKETBEATMSG._serialized_end=12102
  _STOPMETRICBEATMSG._serialized_start=12104
  _STOPMETRICBEATMSG._serialized_end=12185
  _STOPHEARTBEATMSG._serialized_start=12187
  _STOPHEARTBEATMSG._serialized_end=12267
  _STARTFILEBEATMSG._serialized_start=12269
  _STARTFILEBEATMSG._serialized_end=12371
  _STARTPACKETBEATMSG._serialized_start=12373
  _STARTPACKETBEATMSG._serialized_end=12477
  _STARTMETRICBEATMSG._serialized_start=12479
  _STARTMETRICBEATMSG._serialized_end=12583
  _STARTHEARTBEATMSG._serialized_start=12585
  _STARTHEARTBEATMSG._serialized_end=12688
  _STARTHOSTMONITORTHREADMSG._serialized_start=12690
  _STARTHOSTMONITORTHREADMSG._serialized_end=12779
  _STOPHEARTBEATSMSG._serialized_start=12781
  _STOPHEARTBEATSMSG._serialized_end=12841
  _STOPPACKETBEATSMSG._serialized_start=12843
  _STOPPACKETBEATSMSG._serialized_end=12904
  _STOPFILEBEATSMSG._serialized_start=12906
  _STOPFILEBEATSMSG._serialized_end=12965
  _STOPMETRICBEATSMSG._serialized_start=12967
  _STOPMETRICBEATSMSG._serialized_end=13028
  _STARTHOSTMONITORTHREADSMSG._serialized_start=13030
  _STARTHOSTMONITORTHREADSMSG._serialized_end=13099
  _STOPHOSTMANAGERMSG._serialized_start=13101
  _STOPHOSTMANAGERMSG._serialized_end=13183
  _STARTHOSTMANAGERMSG._serialized_start=13185
  _STARTHOSTMANAGERMSG._serialized_end=13268
  _STOPHOSTMANAGERSMSG._serialized_start=13270
  _STOPHOSTMANAGERSMSG._serialized_end=13332
  _EXECUTIONINFODTO._serialized_start=13335
  _EXECUTIONINFODTO._serialized_end=14020
  _RYUMANAGERSINFODTO._serialized_start=14023
  _RYUMANAGERSINFODTO._serialized_end=14252
  _RYUMANAGERSTATUSDTO._serialized_start=14255
  _RYUMANAGERSTATUSDTO._serialized_end=14435
  _HOSTMANAGERSINFODTO._serialized_start=14438
  _HOSTMANAGERSINFODTO._serialized_end=14613
  _HOSTMANAGERSTATUSESDTO._serialized_start=14615
  _HOSTMANAGERSTATUSESDTO._serialized_end=14691
  _HOSTMANAGERSTATUSDTO._serialized_start=14694
  _HOSTMANAGERSTATUSDTO._serialized_end=14862
  _KAFKAMANAGERSINFODTO._serialized_start=14865
  _KAFKAMANAGERSINFODTO._serialized_end=15037
  _KAFKASTATUSDTO._serialized_start=15039
  _KAFKASTATUSDTO._serialized_end=15088
  _OSSECIDSMANAGERSINFODTO._serialized_start=15091
  _OSSECIDSMANAGERSINFODTO._serialized_end=15275
  _OSSECIDSSTATUSDTO._serialized_start=15277
  _OSSECIDSSTATUSDTO._serialized_end=15348
  _SNORTIDSMANAGERSINFODTO._serialized_start=15351
  _SNORTIDSMANAGERSINFODTO._serialized_end=15535
  _SNORTIDSSTATUSDTO._serialized_start=15537
  _SNORTIDSSTATUSDTO._serialized_end=15608
  _GETEXECUTIONINFOMSG._serialized_start=15610
  _GETEXECUTIONINFOMSG._serialized_end=15672
  _STOPCONTAINERSOFEXECUTIONMSG._serialized_start=15674
  _STOPCONTAINERSOFEXECUTIONMSG._serialized_end=15745
  _RUNCONTAINERMSG._serialized_start=15747
  _RUNCONTAINERMSG._serialized_end=15868
  _STARTCONTAINERSOFEXECUTIONMSG._serialized_start=15870
  _STARTCONTAINERSOFEXECUTIONMSG._serialized_end=15942
  _GETELKMANAGERSINFOMSG._serialized_start=15944
  _GETELKMANAGERSINFOMSG._serialized_end=16008
  _ELKMANAGERSINFODTO._serialized_start=16011
  _ELKMANAGERSINFODTO._serialized_end=16226
  _STOPLOGSTASHSERVICEMSG._serialized_start=16228
  _STOPLOGSTASHSERVICEMSG._serialized_end=16293
  _STARTLOGSTASHSERVICEMSG._serialized_start=16295
  _STARTLOGSTASHSERVICEMSG._serialized_end=16361
  _STOPKIBANASERVICEMSG._serialized_start=16363
  _STOPKIBANASERVICEMSG._serialized_end=16426
  _STARTKIBANASERVICEMSG._serialized_start=16428
  _STARTKIBANASERVICEMSG._serialized_end=16492
  _STOPELASTICSERVICEMSG._serialized_start=16494
  _STOPELASTICSERVICEMSG._serialized_end=16558
  _STARTELASTICSERVICEMSG._serialized_start=16560
  _STARTELASTICSERVICEMSG._serialized_end=16625
  _STOPELKSTACKMSG._serialized_start=16627
  _STOPELKSTACKMSG._serialized_end=16685
  _ELKSTATUSDTO._serialized_start=16687
  _ELKSTATUSDTO._serialized_end=16773
  _GETELKSTACKSTATUSMSG._serialized_start=16775
  _GETELKSTACKSTATUSMSG._serialized_end=16838
  _STOPELKMANAGERMSG._serialized_start=16840
  _STOPELKMANAGERMSG._serialized_end=16900
  _STARTELKMANAGERMSG._serialized_start=16902
  _STARTELKMANAGERMSG._serialized_end=16963
  _GETDOCKERSTATSMANAGERSINFOMSG._serialized_start=16965
  _GETDOCKERSTATSMANAGERSINFOMSG._serialized_end=17037
  _DOCKERSTATSMANAGERSINFODTO._serialized_start=17040
  _DOCKERSTATSMANAGERSINFODTO._serialized_end=17243
  _REMOVEALLDOCKERNETWORKSMSG._serialized_start=17245
  _REMOVEALLDOCKERNETWORKSMSG._serialized_end=17273
  _REMOVEDOCKERNETWORKSMSG._serialized_start=17275
  _REMOVEDOCKERNETWORKSMSG._serialized_end=17318
  _DOCKERSTATSMONITORSTATUSDTO._serialized_start=17320
  _DOCKERSTATSMONITORSTATUSDTO._serialized_end=17421
  _GETDOCKERSTATSMANAGERSTATUSMSG._serialized_start=17423
  _GETDOCKERSTATSMANAGERSTATUSMSG._serialized_end=17469
  _STOPDOCKERSTATSMANAGERTHREADMSG._serialized_start=17471
  _STOPDOCKERSTATSMANAGERTHREADMSG._serialized_end=17545
  _CREATEEMULATIONNETWORKSMSG._serialized_start=17547
  _CREATEEMULATIONNETWORKSMSG._serialized_end=17616
  _LISTALLSTOPPEDCONTAINERSMSG._serialized_start=17618
  _LISTALLSTOPPEDCONTAINERSMSG._serialized_end=17647
  _STOPPEDCONTAINERSDTO._serialized_start=17649
  _STOPPEDCONTAINERSDTO._serialized_end=17719
  _LISTALLRUNNINGEMULATIONSMSG._serialized_start=17721
  _LISTALLRUNNINGEMULATIONSMSG._serialized_end=17750
  _RUNNINGEMULATIONSDTO._serialized_start=17752
  _RUNNINGEMULATIONSDTO._serialized_end=17801
  _LISTALLRUNNINGCONTAINERSMSG._serialized_start=17803
  _LISTALLRUNNINGCONTAINERSMSG._serialized_end=17832
  _RUNNINGCONTAINERSDTO._serialized_start=17834
  _RUNNINGCONTAINERSDTO._serialized_end=17904
  _DOCKERCONTAINERDTO._serialized_start=17906
  _DOCKERCONTAINERDTO._serialized_end=17967
  _STARTCONTAINERMSG._serialized_start=17969
  _STARTCONTAINERMSG._serialized_end=18002
  _STARTALLSTOPPEDCONTAINERSMSG._serialized_start=18004
  _STARTALLSTOPPEDCONTAINERSMSG._serialized_end=18034
  _LISTALLDOCKERNETWORKSMSG._serialized_start=18036
  _LISTALLDOCKERNETWORKSMSG._serialized_end=18062
  _DOCKERNETWORKSDTO._serialized_start=18064
  _DOCKERNETWORKSDTO._serialized_end=18122
  _CONTAINERIMAGESDTO._serialized_start=18124
  _CONTAINERIMAGESDTO._serialized_end=18180
  _CONTAINERIMAGEDTO._serialized_start=18182
  _CONTAINERIMAGEDTO._serialized_end=18284
  _LISTALLCONTAINERIMAGESMSG._serialized_start=18286
  _LISTALLCONTAINERIMAGESMSG._serialized_end=18313
  _REMOVECONTAINERIMAGEMSG._serialized_start=18315
  _REMOVECONTAINERIMAGEMSG._serialized_end=18354
  _REMOVEALLCONTAINERIMAGESMSG._serialized_start=18356
  _REMOVEALLCONTAINERIMAGESMSG._serialized_end=18385
  _REMOVEALLSTOPPEDCONTAINERSMSG._serialized_start=18387
  _REMOVEALLSTOPPEDCONTAINERSMSG._serialized_end=18418
  _REMOVECONTAINERMSG._serialized_start=18420
  _REMOVECONTAINERMSG._serialized_end=18454
  _STOPCONTAINERMSG._serialized_start=18456
  _STOPCONTAINERMSG._serialized_end=18488
  _STOPALLRUNNINGCONTAINERSMSG._serialized_start=18490
  _STOPALLRUNNINGCONTAINERSMSG._serialized_end=18519
  _GETTRAFFICMANAGERSINFOMSG._serialized_start=18521
  _GETTRAFFICMANAGERSINFOMSG._serialized_end=18589
  _TRAFFICMANAGERSINFODTO._serialized_start=18592
  _TRAFFICMANAGERSINFODTO._serialized_end=18777
  _TRAFFICMANAGERINFODTO._serialized_start=18779
  _TRAFFICMANAGERINFODTO._serialized_end=18835
  _CLIENTMANAGERSINFODTO._serialized_start=18838
  _CLIENTMANAGERSINFODTO._serialized_end=19015
  _GETCLIENTMANAGERSINFOMSG._serialized_start=19017
  _GETCLIENTMANAGERSINFOMSG._serialized_end=19084
  _STARTTRAFFICGENERATORMSG._serialized_start=19086
  _STARTTRAFFICGENERATORMSG._serialized_end=19174
  _STOPTRAFFICGENERATORMSG._serialized_start=19176
  _STOPTRAFFICGENERATORMSG._serialized_end=19263
  _STOPTRAFFICGENERATORSMSG._serialized_start=19265
  _STOPTRAFFICGENERATORSMSG._serialized_end=19332
  _GETNUMCLIENTSDTO._serialized_start=19335
  _GETNUMCLIENTSDTO._serialized_end=19509
  _GETNUMACTIVECLIENTSMSG._serialized_start=19511
  _GETNUMACTIVECLIENTSMSG._serialized_end=19576
  _STOPCLIENTPOPULATIONMSG._serialized_start=19578
  _STOPCLIENTPOPULATIONMSG._serialized_end=19644
  _STOPCLIENTMANAGERMSG._serialized_start=19646
  _STOPCLIENTMANAGERMSG._serialized_end=19709
  _STARTCLIENTMANAGERMSG._serialized_start=19711
  _STARTCLIENTMANAGERMSG._serialized_end=19775
  _STOPTRAFFICMANAGERSMSG._serialized_start=19777
  _STOPTRAFFICMANAGERSMSG._serialized_end=19842
  _STOPTRAFFICMANAGERMSG._serialized_start=19844
  _STOPTRAFFICMANAGERMSG._serialized_end=19929
  _STARTTRAFFICMANAGERMSG._serialized_start=19931
  _STARTTRAFFICMANAGERMSG._serialized_end=20017
  _CLEANALLEXECUTIONSMSG._serialized_start=20019
  _CLEANALLEXECUTIONSMSG._serialized_end=20042
  _STOPALLEXECUTIONSMSG._serialized_start=20044
  _STOPALLEXECUTIONSMSG._serialized_end=20066
  _STOPEXECUTIONMSG._serialized_start=20068
  _STOPEXECUTIONMSG._serialized_end=20127
  _CLEANEXECUTIONMSG._serialized_start=20129
  _CLEANEXECUTIONMSG._serialized_end=20189
  _STOPALLEXECUTIONSOFEMULATIONMSG._serialized_start=20191
  _STOPALLEXECUTIONSOFEMULATIONMSG._serialized_end=20243
  _CLEANALLEXECUTIONSOFEMULATIONMSG._serialized_start=20245
  _CLEANALLEXECUTIONSOFEMULATIONMSG._serialized_end=20298
  _GETCSLELOGFILESMSG._serialized_start=20300
  _GETCSLELOGFILESMSG._serialized_end=20320
  _GETLOGFILEMSG._serialized_start=20322
  _GETLOGFILEMSG._serialized_end=20351
  _STARTCONTAINERSINEXECUTIONMSG._serialized_start=20353
  _STARTCONTAINERSINEXECUTIONMSG._serialized_end=20425
  _ATTACHCONTAINERSTONETWORKSINEXECUTIONMSG._serialized_start=20427
  _ATTACHCONTAINERSTONETWORKSINEXECUTIONMSG._serialized_end=20510
  _INSTALLLIBRARIESMSG._serialized_start=20512
  _INSTALLLIBRARIESMSG._serialized_end=20574
  _APPLYKAFKACONFIGMSG._serialized_start=20576
  _APPLYKAFKACONFIGMSG._serialized_end=20638
  _STARTSDNCONTROLLERMSG._serialized_start=20640
  _STARTSDNCONTROLLERMSG._serialized_end=20704
  _APPLYRESOUCECONSTRAINTSMSG._serialized_start=20706
  _APPLYRESOUCECONSTRAINTSMSG._serialized_end=20775
  _CREATEOVSSWITCHESMSG._serialized_start=20777
  _CREATEOVSSWITCHESMSG._serialized_end=20840
  _PINGEXECUTIONMSG._serialized_start=20842
  _PINGEXECUTIONMSG._serialized_end=20901
  _CONFIGUREOVSMSG._serialized_start=20903
  _CONFIGUREOVSMSG._serialized_end=20961
  _STARTSDNCONTROLLERMONITORMSG._serialized_start=20963
  _STARTSDNCONTROLLERMONITORMSG._serialized_end=21034
  _CREATEUSERSMSG._serialized_start=21036
  _CREATEUSERSMSG._serialized_end=21093
  _CREATEVULNSMSG._serialized_start=21095
  _CREATEVULNSMSG._serialized_end=21152
  _CREATEFLAGSMSG._serialized_start=21154
  _CREATEFLAGSMSG._serialized_end=21211
  _CREATETOPOLOGYMSG._serialized_start=21213
  _CREATETOPOLOGYMSG._serialized_end=21273
  _STARTTRAFFICMANAGERSMSG._serialized_start=21275
  _STARTTRAFFICMANAGERSMSG._serialized_end=21341
  _STARTTRAFFICGENERATORSMSG._serialized_start=21343
  _STARTTRAFFICGENERATORSMSG._serialized_end=21411
  _STARTCLIENTPOPULATIONMSG._serialized_start=21413
  _STARTCLIENTPOPULATIONMSG._serialized_end=21480
  _STARTKAFKACLIENTPRODUCERMSG._serialized_start=21482
  _STARTKAFKACLIENTPRODUCERMSG._serialized_end=21552
  _STOPKAFKACLIENTPRODUCERMSG._serialized_start=21554
  _STOPKAFKACLIENTPRODUCERMSG._serialized_end=21623
  _STARTSNORTIDSESMSG._serialized_start=21625
  _STARTSNORTIDSESMSG._serialized_end=21686
  _STARTSNORTIDSESMONITORTHREADSMSG._serialized_start=21688
  _STARTSNORTIDSESMONITORTHREADSMSG._serialized_end=21763
  _STARTOSSECIDSESMSG._serialized_start=21765
  _STARTOSSECIDSESMSG._serialized_end=21826
  _STARTOSSECIDSESMONITORTHREADSMSG._serialized_start=21828
  _STARTOSSECIDSESMONITORTHREADSMSG._serialized_end=21903
  _STARTELKSTACKMSG._serialized_start=21905
  _STARTELKSTACKMSG._serialized_end=21964
  _STARTHOSTMANAGERSMSG._serialized_start=21966
  _STARTHOSTMANAGERSMSG._serialized_end=22029
  _APPLYFILEBEATCONFIGSMSG._serialized_start=22031
  _APPLYFILEBEATCONFIGSMSG._serialized_end=22097
  _APPLYPACKETBEATCONFIGSMSG._serialized_start=22099
  _APPLYPACKETBEATCONFIGSMSG._serialized_end=22167
  _APPLYMETRICBEATCONFIGSMSG._serialized_start=22169
  _APPLYMETRICBEATCONFIGSMSG._serialized_end=22237
  _APPLYHEARTBEATCONFIGSMSG._serialized_start=22239
  _APPLYHEARTBEATCONFIGSMSG._serialized_end=22306
  _STARTFILEBEATSMSG._serialized_start=22308
  _STARTFILEBEATSMSG._serialized_end=22390
  _STARTPACKETBEATSMSG._serialized_start=22392
  _STARTPACKETBEATSMSG._serialized_end=22476
  _STARTMETRICBEATSMSG._serialized_start=22478
  _STARTMETRICBEATSMSG._serialized_end=22562
  _STARTHEARTBEATSMSG._serialized_start=22564
  _STARTHEARTBEATSMSG._serialized_end=22647
  _GETDOCKERSTATSMANAGERLOGSMSG._serialized_start=22649
  _GETDOCKERSTATSMANAGERLOGSMSG._serialized_end=22679
  _GETPROMETHEUSLOGSMSG._serialized_start=22681
  _GETPROMETHEUSLOGSMSG._serialized_end=22703
  _GETNODEEXPORTERLOGSMSG._serialized_start=22705
  _GETNODEEXPORTERLOGSMSG._serialized_end=22729
  _GETCADVISORLOGSMSG._serialized_start=22731
  _GETCADVISORLOGSMSG._serialized_end=22751
  _GETPGADMINLOGSMSG._serialized_start=22753
  _GETPGADMINLOGSMSG._serialized_end=22772
  _GETGRAFANALOGSMSG._serialized_start=22774
  _GETGRAFANALOGSMSG._serialized_end=22793
  _GETNGINXLOGSMSG._serialized_start=22795
  _GETNGINXLOGSMSG._serialized_end=22812
  _GETDOCKERLOGSMSG._serialized_start=22814
  _GETDOCKERLOGSMSG._serialized_end=22832
  _GETPOSTGRESQLLOGSMSG._serialized_start=22834
  _GETPOSTGRESQLLOGSMSG._serialized_end=22856
  _GETFLASKLOGSMSG._serialized_start=22858
  _GETFLASKLOGSMSG._serialized_end=22875
  _LOGSDTO._serialized_start=22877
  _LOGSDTO._serialized_end=22900
  _OPERATIONOUTCOMEDTO._serialized_start=22902
  _OPERATIONOUTCOMEDTO._serialized_end=22940
  _GETNODESTATUSMSG._serialized_start=22942
  _GETNODESTATUSMSG._serialized_end=22960
  _NODESTATUSDTO._serialized_start=22963
  _NODESTATUSDTO._serialized_end=23270
  _SERVICESTATUSDTO._serialized_start=23272
  _SERVICESTATUSDTO._serialized_end=23307
  _STARTPOSTGRESQLMSG._serialized_start=23309
  _STARTPOSTGRESQLMSG._serialized_end=23329
  _STARTCADVISORMSG._serialized_start=23331
  _STARTCADVISORMSG._serialized_end=23349
  _STARTNODEEXPORTERMSG._serialized_start=23351
  _STARTNODEEXPORTERMSG._serialized_end=23373
  _STARTGRAFANAMSG._serialized_start=23375
  _STARTGRAFANAMSG._serialized_end=23392
  _STARTPROMETHEUSMSG._serialized_start=23394
  _STARTPROMETHEUSMSG._serialized_end=23414
  _STARTPGADMINMSG._serialized_start=23416
  _STARTPGADMINMSG._serialized_end=23433
  _STARTNGINXMSG._serialized_start=23435
  _STARTNGINXMSG._serialized_end=23450
  _STARTFLASKMSG._serialized_start=23452
  _STARTFLASKMSG._serialized_end=23467
  _STARTDOCKERSTATSMANAGERMSG._serialized_start=23469
  _STARTDOCKERSTATSMANAGERMSG._serialized_end=23497
  _STARTDOCKERSTATSMANAGERTHREADMSG._serialized_start=23499
  _STARTDOCKERSTATSMANAGERTHREADMSG._serialized_end=23574
  _STARTDOCKERENGINEMSG._serialized_start=23576
  _STARTDOCKERENGINEMSG._serialized_end=23598
  _STOPPOSTGRESQLMSG._serialized_start=23600
  _STOPPOSTGRESQLMSG._serialized_end=23619
  _STOPCADVISORMSG._serialized_start=23621
  _STOPCADVISORMSG._serialized_end=23638
  _STOPNODEEXPORTERMSG._serialized_start=23640
  _STOPNODEEXPORTERMSG._serialized_end=23661
  _STOPGRAFANAMSG._serialized_start=23663
  _STOPGRAFANAMSG._serialized_end=23679
  _STOPPROMETHEUSMSG._serialized_start=23681
  _STOPPROMETHEUSMSG._serialized_end=23700
  _STOPPGADMINMSG._serialized_start=23702
  _STOPPGADMINMSG._serialized_end=23718
  _STOPNGINXMSG._serialized_start=23720
  _STOPNGINXMSG._serialized_end=23734
  _STOPFLASKMSG._serialized_start=23736
  _STOPFLASKMSG._serialized_end=23750
  _STOPDOCKERSTATSMANAGERMSG._serialized_start=23752
  _STOPDOCKERSTATSMANAGERMSG._serialized_end=23779
  _STOPDOCKERENGINEMSG._serialized_start=23781
  _STOPDOCKERENGINEMSG._serialized_end=23802
  _CLUSTERMANAGER._serialized_start=23805
  _CLUSTERMANAGER._serialized_end=38462
# @@protoc_insertion_point(module_scope)
